OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Adreces d'interès",
    "You bookmarked \"%s\"" : "Heu afegit a les adreces d’interès \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s ha afegit a les adreces d’interès \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Algú ha afegit a les adreces d’interès \"%s\"",
    "You deleted \"%s\"" : "Heu suprimit \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s ha suprimit \"%2$s\"",
    "Someone deleted \"%s\"" : "Algú ha suprimit \"%s\"",
    "You created folder \"%s\"" : "Heu creat la carpeta \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s ha creat la carpeta \"%2$s\"",
    "Someone created folder \"%s\"" : "Algú ha creat la carpeta \"%s\"",
    "You moved folder \"%s\"" : "Heu mogut la carpeta \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s ha mogut la carpeta \"%2$s\"",
    "Someone moved folder \"%s\"" : "Algú ha mogut la carpeta \"%s\"",
    "You deleted folder \"%s\"" : "Heu suprimit la carpeta \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s ha suprimit la carpeta \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Algú ha suprimit la carpeta \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Heu compartit la carpeta \"%1$s\" amb %2$s",
    "You shared folder \"%s\" with someone" : "Heu compartit la carpeta \"%s\" amb algú",
    "%1$s shared folder \"%2$s\" with you" : "%1$s ha compartit la carpeta \"%2$s\" amb tu",
    "Someone shared folder \"%s\" with you" : "Algú ha compartit la carpeta \"%s\" amb tu",
    "You unshared folder \"%1$s\" with %2$s" : "Heu deixat de compartit la carpeta \"%1$s\" amb %2$s",
    "You unshared folder \"%s\" with someone" : "Heu deixat de compartit la carpeta \"%s\" amb algú",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s ha deixat de compartir la carpeta \"%2$s\" amb vostè",
    "Someone unshared folder \"%s\" with you" : "Algú ha deixat de compartir la carpeta \"%s\" amb tu",
    "No file provided for import" : "No s'ha proporcionat cap fitxer per importació",
    "Bookmarks shared by %s" : "Adreces d'interès compartides per %s",
    "Frequent bookmarks" : "Adreces d'interès freqüents",
    "Recent bookmarks" : "Adreces d'interès recents",
    "Bookmark" : "Adreça d'interès",
    "Bookmark deleted" : "S'ha suprimit l'adreça d'interès",
    "Bookmark created" : "S’ha creat una adreça d'interès",
    "Bookmark moved" : "S' ha mogut l'adreça d'interès",
    "Bookmark updated" : "Adreça d'interès actualitzada",
    "Create bookmark" : "Crea una adreça d'interès",
    "Takes a link and adds it to your collection of bookmarks." : "Pren un enllaç i l'afegeix a la seva col·lecció d'adreces d'interès.",
    "Bookmarks Backups" : "Còpies de seguretat d’adreces d'interès",
    "Enter new title" : "Introduïu un títol nou",
    "Select bookmark" : "Seleccioneu una adreça d'interès",
    "Details" : "Detalls",
    "Rename" : "Canvia'n el nom",
    "Copy link" : "Copia l'enllaç",
    "Move" : "Mou",
    "Add to folders" : "Afegeix-ho a les carpetes",
    "Do you really want to delete this bookmark?" : "Realment voleu suprimir aquesta adreça d'interès?",
    "Link copied to clipboard" : "Enllaç copiat al porta-retalls",
    "Content pending" : "Contingut pendent",
    "This content is being downloaded for offline use. Please check back later." : "Aquest contingut s'està baixant per utilitzar-lo fora de línia. Si us plau, torneu-ho a comprovar més tard.",
    "Bookmarked {time} ago" : "Marcat fa {time}",
    "Bookmarked on {date}" : "Marcat a {date}",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Les adreces d'interès dels fitxers del web, com ara fotografies o PDF, es desaran automàticament als fitxers de Nextcloud, de manera que encara les podeu trobar fins i tot quan l'enllaç estigui desconnectat.",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Els enllaços marcats es revisen regularment i els que no es poden accedir s'enumeren aquí.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Podeu compartir carpetes d'adreces d'interès amb altres persones. Totes les carpetes compartides amb tu es mostren aquí.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Una adreça d'interès pot estar en diverses carpetes alhora. En actualitzar-la, s'actualitzaran totes les còpies. Totes les adreces d'interès duplicades s'enumeren aquí per comoditat.",
    "Open all selected" : "Obre totes els seleccionats",
    "Move selection" : "Mou la selecció",
    "Edit tags of selection" : "Edició de les etiquetes de la selecció",
    "Delete selection" : "Suprimeix la selecció",
    "Select all" : "Selecciona-ho tot",
    "Cancel selection" : "Cancel·la la selecció",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Carpetes {folders} seleccionades i adreces d'interès {bookmarks}",
    "Do you really want to delete these items?" : "Realment voleu suprimir aquests elements?",
    "Go back" : "Torna enrere",
    "Share folder" : "Comparteix la carpeta",
    "Select one or more tags" : "Seleccionau una o més etiquetes",
    "New" : "Nou",
    "New bookmark" : "Adreça d'interès nova",
    "New folder" : "Carpeta nova",
    "Change to grid view" : "Canvia a la visualització de quadrícula",
    "Change to list view" : "Canvia el mode de visualització a llista",
    "Copy RSS Feed of current view" : "Copia el canal RSS de la visualització actual",
    "The RSS feed requires authentication with your Nextcloud credentials" : "El canal RSS requereix autenticació amb les vostres credencials de Nextcloud",
    "Search" : "Cercar",
    "Empty trash bin" : "Buida la paperera",
    "Sort by created date" : "Ordena per data de creació",
    "Sort by last modified" : "Ordena per darrera modificació",
    "Sort by title" : "Ordena per títol",
    "Sort by click count" : "Ordena per recompte de clics",
    "Sort by manual order" : "Ordena per ordre manual",
    "Sort by URL" : "Ordena per URL",
    "RSS feed copied" : "Canal RSS copiat",
    "Enter a link" : "Introduïu un enllaç",
    "Enter a title" : "Escriviu el títol",
    "No bookmarks found" : "No s'ha trobat cap adreça d'interès",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} carpetes i {bookmarks} adreces d'interès",
    "Welcome to Bookmarks" : "Benvingut a Adreces d'interès",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Aquesta aplicació us permet gestionar enllaços als vostres llocs preferits al web. Ordena les teves adreces d'interès en carpetes, etiqueta'ls amb etiquetes i comparteix-les amb els altres! L'aplicació comprovarà regularment la disponibilitat de tots els vostres enllaços i mostrarà els enllaços no disponibles. Si afegiu un enllaç a un fitxer al web, el fitxer es baixarà automàticament als vostres fitxers Nextcloud. També podeu importar adreces d'interès exportades des d'altres serveis o sincronitzar directament les adreces d'interès de tots els vostres navegadors amb aquesta aplicació.",
    "Add a bookmark" : "Afegeix una adreça d'interès",
    "Import bookmarks" : "Importa adreces d'interès",
    "Sync with your browser" : "Sincronitzar amb el vostre navegador",
    "Select folder" : "Trieu una carpeta",
    "Enter folder title" : "Escriviu el títol de la carpeta",
    "Shared by {user}" : "Compartit per {user}",
    "Rename folder" : "Canvia el nom de la carpeta",
    "Move folder" : "Mou la carpeta",
    "Choose folder" : "Trieu carpeta",
    "Submit" : "Envia",
    "Cancel" : "Cancel·la",
    "Deleting bookmarks" : "S'estan suprimint les adreces d'interès",
    "Deleting selection" : "S'està suprimint la selecció",
    "Importing bookmarks" : "S'estan important les adreces d'interès",
    "Moving selection" : "S'està movent la selecció",
    "Adding selection to folders" : "Afegint selecció a les carpetes",
    "All bookmarks" : "Totes les adreces d'interès",
    "Recent" : "Recents",
    "Shared with you" : "Compartit amb vós",
    "Files" : "Fitxers",
    "Duplicates" : "Duplicats",
    "Broken links" : "Enllaços trencats",
    "New tag" : "Nova etiqueta",
    "Search tags" : "Cerca etiquetes",
    "Delete" : "Suprimeix",
    "Untagged" : "Sense etiqueta",
    "{used} bookmarks of {available} available" : "{used} Adreces d'interès de {available} disponibles",
    "No bookmarked files" : "No hi ha fitxers marcats",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Les adreces d'interès a fitxers com ara fotos o PDF es desaran automàticament als fitxers Nextcloud, de manera que encara els podeu trobar fins i tot quan l'enllaç es desconnecti.",
    "No broken links" : "No hi ha enllaços trencats",
    "No shared folders" : "No hi ha carpetes compartides",
    "No duplicated bookmarks" : "No hi ha adreces d'interès duplicades",
    "No bookmarks here" : "No hi ha cap adreça d'interès",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Afegiu adreces d'interès manualment o importeu-ne d'un fitxer HTML.",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Introduïu el camí d'una carpeta als fitxers on s'han d'emmagatzemar les adreces d’interès dels fitxers.",
    "Enter the path of a folder in your Files where backups will be stored." : "Introduïu el camí d'una carpeta als vostres fitxers on s'emmagatzemaran les còpies de seguretat.",
    "Client apps" : "Aplicacions de client",
    "Also check out the collection of client apps that integrate with this app: " : "Feu també un cop d'hora al conjunt d'aplicacions client que s'integren amb aquesta aplicació: ",
    "Install web app" : "Instal·la l'aplicació web",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Pots instal·lar aquesta aplicació a la pantalla d'inici del dispositiu per accedir ràpidament les adreces d'interès al teu telèfon. Pots tornar a suprimir fàcilment l'aplicació de la pantalla d'inici si no t'agrada.",
    "Install on home screen" : "Instal·la a la pantalla d'inici",
    "Bookmarklet" : "Miniaplicació d'adreces d'interès",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Arrossegueu-lo a les adreces d'interès del navegador i feu-hi clic per afegir ràpidament una pàgina web a les adreces d'interès.",
    "Add to {instanceName}" : "Afegeix a {instanceName}",
    "Need help?" : "Necessiteu ajuda?",
    "Archive path" : "Camí de l'arxiu",
    "Backup path" : "Camí de la còpia de seguretat",
    "Please select \"Add to home screen\" in your browser menu" : "Seleccioneu «Afegeix a la pantalla d'inici» en el menú del vostre navegador",
    "Title" : "Títol",
    "Link" : "Enllaç",
    "Untitled folder" : "Carpeta sense nom",
    "Root folder" : "Carpeta d'arrel",
    "Tags" : "Etiquetes",
    "Select tags and create new ones" : "Seleccioneu etiquetes i creeu-ne de noves",
    "Notes" : "Notes",
    "Notes for this bookmark …" : "Notes per a aquesta adreça d'interès …",
    "Archived file" : "Obre el fitxer arxivat",
    "Download file" : "Baixa el fitxer",
    "Open file location" : "Obre la ubicació del fitxer",
    "Created {time} ago" : "Creat fa {time}",
    "Created on {date}" : "Creat en {date}",
    "Owner" : "Propietari",
    "Sharing" : "Compartició",
    "Select a user or group" : "Seleccioneu un usuari o un grup",
    "Share link" : "Enllaç de compartició",
    "Reading allowed" : "Lectura permesa",
    "Copy RSS feed" : "Copia canal RSS",
    "Delete link" : "Suprimeix l'enllaç",
    "Create public link" : "Creació d'un enllaç públic",
    "Resharing allowed" : "Tornar a compartir permés",
    "Editing allowed" : "Edició permesa",
    "Allow editing" : "Permet l'edició",
    "Allow resharing" : "Permet compartir de nou",
    "Remove share" : "Suprimeix la compartició",
    "Link copied" : "Enllaç copiat",
    "Privacy" : "Privadesa",
    "Enable accessing and collecting information from the web pages you add" : "Habiliteu l'accés i la recopilació d'informació de les pàgines web que afegiu",
    "Performance" : "Rendiment",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "En una instal·lació amb molts usuaris pot ser útil restringir el nombre d'adreces d'interès per compte.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Nombre màxim permès d'adreces d'interès per compte. (0 sense límit; per defecte no té límit)",
    "Previews" : "Previsualitzacions",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Podeu registrar-vos de forma gratuïta a screeenly.com configurar el vostre propi servidor.",
    "Screeenly API URL" : "URL de l'API de Screeenly",
    "Screeenly API key" : "Clau API de Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Clau de l’API de ScreenshotMachine",
    "Webshot" : "Foto web",
    "Webshot API URL" : "URL de l'API de webshot",
    "Pageres CLI" : "Pageres CLI",
    "Pageres ENV variables" : "Variables ENV Pageres",
    "Failed to save settings" : "Ha fallat desar els paràmetres",
    "Failed to load settings" : "Ha fallat carregar els paràmetres",
    "This URL is already bookmarked! Overwrite?" : "Ja teniu aquest URL als Adreces d'interès. Voleu sobreescriure'l?",
    "Enter bookmark title" : "Escriviu el títol de l'adreça d'interès",
    "Enter bookmark URL" : "Introduïu l'adreça URL de l'adreça d'interès",
    "Folder" : "Carpeta",
    "Root Folder" : "Carpeta arrel",
    "Save" : "Desa",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "L'accés a la xarxa està inhabilitat per defecte. Aneu als paràmetres de l'administrador de l'aplicació Adreces d'interès per permetre obtenir previsualitzacions i favicons.",
    "What's new?" : "Quines novetats hi ha?",
    "What" : "Què",
    "Failed to count unavailable bookmarks" : "No s'han pogut comptar les adreces d'interès no disponibles",
    "Failed to count archived bookmarks" : "No s'han pogut comptar les adreces d'interès arxivades",
    "Failed to count duplicated bookmarks" : "No s'han pogut comptar les adreces d'interès duplicades",
    "Failed to load bookmark" : "No s'ha pogut carregar l'adreça d'interès",
    "Failed to find existing bookmark" : "Ha fallat trobar l'adreça d'interès existent",
    "Failed to create bookmark" : "Ha fallat crear l'adreça d'interès",
    "Failed to save bookmark" : "Ha fallat desar l'adreça d'interès",
    "Failed to move bookmark" : "Ha fallat moure l'adreça d'interès",
    "Failed to copy bookmark" : "No s'ha pogut copiar l'adreça d'interès",
    "Failed to delete bookmark" : "Ha fallat suprimir l'adreça d'interès",
    "Failed to rename tag" : "No s'ha pogut canviar el nom de l'etiqueta",
    "Failed to load tags" : "Ha fallat carregar les etiquetes",
    "Failed to load folders" : "Ha fallat carregar les carpetes",
    "Failed to delete folder" : "Ha fallat suprimir la carpeta",
    "Failed to create folder" : "Ha fallat crear la carpeta",
    "Failed to fetch bookmarks." : "Ha fallat obtenir les adreces d'interès.",
    "Failed to load setting {key}" : "No s'ha pogut carregar el paràmetre {key}",
    "Failed to update share {shareId}" : "No s'ha pogut actualitzar la compartició {shareId}",
    "Failed to delete share {shareId}" : "No s'ha pogut suprimir la compartició {shareId}",
    "Create bookmarks for mentioned links" : "Creeu adreces d'interès per als enllaços esmentats",
    "No links found in this message" : "No s'han trobat enllaços en aquest missatge",
    "Bookmarks feed" : "Canal d'adreces d'interès"
},
"nplurals=2; plural=(n != 1);");
