OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "Details" : "Detalhes",
    "Rename" : "Renomear",
    "Copy link" : "Copiar hiperligação",
    "Move" : "Mover",
    "Link copied to clipboard" : "Ligação copiada para a área de transferência",
    "Select all" : "Seleccionar todos",
    "Go back" : "Voltar",
    "Share folder" : "Partilhar pasta",
    "New" : "Novo",
    "New folder" : "Nova pasta",
    "Search" : "Pesquisa sobre",
    "Empty trash bin" : "Esvaziar a reciclagem",
    "Add a bookmark" : "Adicionar um marcador",
    "Rename folder" : "Renomear pasta",
    "Choose folder" : "Escolher pasta",
    "Submit" : "Submeter",
    "Cancel" : "Cancelar",
    "All bookmarks" : "Todos os marcadores",
    "Recent" : "Recentes",
    "Shared with you" : "Partilhado consigo",
    "Files" : "Ficheiros",
    "Delete" : "Apagar",
    "Need help?" : "Precisa de ajuda?",
    "Title" : "Título",
    "Link" : "Link",
    "Root folder" : "Pasta raiz",
    "Tags" : "Marcações",
    "Notes" : "Notas",
    "Download file" : "Transferir ficheiro",
    "Owner" : "Proprietário",
    "Sharing" : "Partilha",
    "Select a user or group" : "Selecionar utilizador ou grupo",
    "Share link" : "Share link",
    "Allow editing" : "Permitir edição",
    "Allow resharing" : "Permitir repartilha",
    "Link copied" : "Link copiado",
    "Privacy" : "Privacidade",
    "Failed to save settings" : "Erro ao gravar as definições",
    "Folder" : "Pasta",
    "Save" : "Guardar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
