OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Favoritter",
    "You bookmarked \"%s\"" : "Du satte bogmærke for \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s satte bogmærkede \"%2$s\"",
    "Someone bookmarked \"%s\"" : "En person bogmærkede \"%s\"",
    "You deleted \"%s\"" : "Du slettede \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s slettede \"%2$s\"",
    "Someone deleted \"%s\"" : "En person slettede \"%s\"",
    "You created folder \"%s\"" : "Du oprettede mappen \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s oprettede mappen \"%2$s\"",
    "Someone created folder \"%s\"" : "En person oprettede mappen \"%s\"",
    "You moved folder \"%s\"" : "Du flyttede mappen \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s flyttede mappen \"%2$s\"",
    "Someone moved folder \"%s\"" : "En person flyttede mappen \"%s\"",
    "You deleted folder \"%s\"" : "Du slettede mappen \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s slettede mappen \"%2$s\"",
    "Someone deleted folder \"%s\"" : "En person slettede mappen \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Du delte mappen \"%1$s\" med %2$s",
    "You shared folder \"%s\" with someone" : "Du slettede mappen \"%s\" med en anden",
    "%1$s shared folder \"%2$s\" with you" : "%1$s delte mappen \"%2$s\" med dig",
    "Someone shared folder \"%s\" with you" : "En person delte mappen \"%s\" med dig",
    "You unshared folder \"%1$s\" with %2$s" : "Du stoppede deling af mapen \"%1$s\" med %2$s",
    "You unshared folder \"%s\" with someone" : "De stoppede deling af mappen \"%s\" med en person",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s stoppede deling af mappen \"%2$s\" med dig",
    "Someone unshared folder \"%s\" with you" : "En person stoppede deling af mappen \"%s\" med dig",
    "No file provided for import" : "Ingen fil til import",
    "Bookmarks shared by %s" : "Bogmærker delt af %s",
    "Frequent bookmarks" : "Hyppige bogmærker",
    "Recent bookmarks" : "Seneste bogmærker",
    "Bookmark" : "Bogmærke",
    "Bookmark deleted" : "Bogmærke blev slettet",
    "Bookmark created" : "Bogmærke blev oprettet",
    "Bookmark moved" : "Bogmærke blev flyttet",
    "Bookmark updated" : "Bogmærke blev opdateret",
    "Create bookmark" : "Opret bogmærke",
    "Takes a link and adds it to your collection of bookmarks." : "Tager imod et link og føjer det til din bogmærkesamling.",
    "Bookmarks Backups" : "Backup af bogmærker",
    "Enter new title" : "Angiv ny titel",
    "Select bookmark" : "Vælg bogmærke",
    "Details" : "Detaljer",
    "Rename" : "Omdøb",
    "Copy link" : "Kopiér link",
    "Move" : "Flyt",
    "Add to folders" : "Tilføj til mapper",
    "Do you really want to delete this bookmark?" : "Vil du virkelig slette dette bogmærke?",
    "Link copied to clipboard" : "Link kopieret til udklipsholder",
    "Content pending" : "Afventende indhold",
    "This content is being downloaded for offline use. Please check back later." : "Dette indhold downloades til offline-brug. Tjek venligst igen senere.",
    "Bookmarked {time} ago" : "Bogmærke oprettet for {time} siden",
    "Bookmarked on {date}" : "Bogmærke oprettet den {date}",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bogmærker til filer på internettet såsom billeder eller pdf'er vil automatisk blive gemt til dine Nextcloud-filer, så du stadig kan finde dem når forbindelsen går offline.",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Bogmærkede links tjekkes jævnligt og de som ikke kan nås vises her.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Du kan dele bogmærkemapper med andre. Alle mapper som deles af dig vises her.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Et bogmærke kan være i flere mapper på samme tid. Når det opdateres, så opdateres alle kopier. Alle dubletter af bogmærker vises her for nemhedens skyld.",
    "Open all selected" : "Åbn alle valgte",
    "Move selection" : "Flyt valgte",
    "Edit tags of selection" : "Rediger markeringer",
    "Delete selection" : "Slet valgte",
    "Select all" : "Vælg alle",
    "Cancel selection" : "Annuller valg",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Valgte {folders} mapper og {bookmarks} bogmærker",
    "Do you really want to delete these items?" : "Vil du virkelig slette disse elementer?",
    "Go back" : "Gå tilbage",
    "Share folder" : "Del mappe",
    "Select one or more tags" : "Vælg et eller flere tags",
    "New" : "Ny",
    "New bookmark" : "Nyt Bogmærke",
    "New folder" : "Ny mappe",
    "Change to grid view" : "Skift til gittervisning",
    "Change to list view" : "Skift til listevisning",
    "Copy RSS Feed of current view" : "Kopier RSS-feed af den aktuelle visning",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS-feedet kræver godkendelse med dine Nextcloud-legitimationsoplysninger",
    "Search" : "Søg",
    "Empty trash bin" : "Tøm papirkurv",
    "Sort by created date" : "Sorter efter oprettelsesdato",
    "Sort by last modified" : "Sorter efter sidst ændret",
    "Sort by title" : "Sorter efter titel",
    "Sort by click count" : "Sorter efter klikantal",
    "Sort by manual order" : "Sorter efter manuel rækkefølge",
    "Sort by URL" : "Sorter efter URL",
    "RSS feed copied" : "RSS-feed kopieret",
    "Enter a link" : "Indtast et link",
    "Enter a title" : "Indtast en titel",
    "No bookmarks found" : "Ingen bogmærker fundet",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} mapper og {bookmarks} bogmærker",
    "Welcome to Bookmarks" : "Velkommen til Bogmærker",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Denne app giver dig mulighed for at administrere links til dine yndlingssteder på nettet. Sorter dine bogmærker i mapper, mærk dem med tags og del dem med andre! Appen vil regelmæssigt tjekke alle dine links for tilgængelighed og vise utilgængelige links. Hvis du tilføjer et link til en fil på nettet, vil filen automatisk blive downloadet til dine Nextcloud-filer. Du kan også importere bogmærker eksporteret fra andre tjenester eller direkte synkronisere bogmærker fra alle dine browsere med denne app.",
    "Add a bookmark" : "Tilføj et bogmærke",
    "Import bookmarks" : "Importer bogmærker",
    "Sync with your browser" : "Synkroniser med din browser",
    "Select folder" : "Vælg mappe",
    "Enter folder title" : "Angiv folder navn",
    "Shared by {user}" : "Delt af {user}",
    "Rename folder" : "Omdøb mappe",
    "Move folder" : "Flyt mappe",
    "Choose folder" : "Vælg mappe",
    "Submit" : "Tilføj",
    "Cancel" : "Annullér",
    "Deleting bookmarks" : "Sletter bogmærker",
    "Deleting selection" : "Sletter valg",
    "Importing bookmarks" : "Importerer bogmærker",
    "Moving selection" : "Flytter valgte",
    "Adding selection to folders" : "Tilføjelse af valg til mapper",
    "All bookmarks" : "Alle bogmærker",
    "Recent" : "Seneste",
    "Shared with you" : "Shared with you",
    "Files" : "Filer",
    "Duplicates" : "Dubletter",
    "Broken links" : "Ødelagte links",
    "New tag" : "Nyt tag",
    "Search tags" : "Søg tags",
    "Delete" : "Slet",
    "Untagged" : "Fravalgt",
    "{used} bookmarks of {available} available" : "{used} bogmærker af {available} tilgængelige",
    "No bookmarked files" : "Ingen bogmærkede filer",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bogmærker til filer som fotos eller PDF'er gemmes automatisk i dine Nextcloud-filer, så du stadig kan finde dem, selv når linket går offline.",
    "No broken links" : "Ingen ødelagte links",
    "No shared folders" : "Ingen delte mapper",
    "No duplicated bookmarks" : "Ingen duplikerede bogmærker",
    "No bookmarks here" : "Ingen bogmærker her",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Tilføj bogmærker manuelt eller importer bogmærker fra en HTML-fil.",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Indtast stien til en mappe i dine filer, hvor bogmærkede filer skal gemmes.",
    "Enter the path of a folder in your Files where backups will be stored." : "Indtast stien til en mappe i dine filer, hvor sikkerhedskopier vil blive gemt.",
    "Client apps" : "Klient apps",
    "Also check out the collection of client apps that integrate with this app: " : "Tjek også samlingen af klientapps, der integreres med denne app:",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Du kan installere denne app på din enheds startskærm for hurtigt at få adgang til dine bogmærker på din telefon. Du kan nemt fjerne appen fra din startskærm igen, hvis du ikke kan lide den.",
    "Install on home screen" : "Installer på startskærmen",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Træk dette til dine browserbogmærker, og klik på det for hurtigt at bogmærke en webside.",
    "Add to {instanceName}" : "Tilføj til {instanceName}",
    "Need help?" : "Brug for hjælp?",
    "Archive path" : "Arkivsti",
    "Backup path" : "Backup sti",
    "Please select \"Add to home screen\" in your browser menu" : "Vælg venligst \"Tilføj til startskærmen\" i din browsermenu",
    "Title" : "Titel",
    "Link" : "Link",
    "Untitled folder" : "Unavngivet mappe",
    "Root folder" : "Rodmappe",
    "Tags" : "Tags",
    "Select tags and create new ones" : "Vælg tags og opret nye",
    "Notes" : "Noter",
    "Notes for this bookmark …" : "Noter til dette bogmærke...",
    "Archived file" : "Arkiveret fil",
    "Download file" : "Download fil",
    "Open file location" : "Åbn filplacering",
    "Created {time} ago" : "Oprettet for {time} siden",
    "Created on {date}" : "Oprettet den {date}",
    "Owner" : "Ejer",
    "Sharing" : "Deling",
    "Select a user or group" : "Vælg en bruger eller gruppe",
    "Share link" : "Share link",
    "Reading allowed" : "Læsning tilladt",
    "Copy RSS feed" : "Kopier RSS-feed",
    "Delete link" : "Slet link",
    "Create public link" : "Opret offentligt link",
    "Resharing allowed" : "Videredeling tilladt",
    "Editing allowed" : "Redigering tilladt",
    "Allow editing" : "Tillad redigering",
    "Allow resharing" : "Tillad videredeling",
    "Remove share" : "Fjern deling",
    "Link copied" : "Link kopieret",
    "Privacy" : "Privatliv",
    "Enable accessing and collecting information from the web pages you add" : "Aktiver adgang til og indsamling af oplysninger fra de websider, du tilføjer",
    "Performance" : "Ydelse",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "I en installation med mange brugere kan det være nyttigt at begrænse antallet af bogmærker pr. konto.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksimalt tilladt antal bogmærker pr. konto. (0 for ingen grænse; standard er ingen grænse)",
    "Previews" : "Forhåndsvisning",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Du kan enten tilmelde dig gratis på screeneenly.com eller opsætte din egen server.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API nøgle",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API nøgle",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Pageres CLI" : "Pageres CLI",
    "Pageres ENV variables" : "Pageres ENV variabler",
    "Failed to save settings" : "Kunne ikke gemme indstillinger",
    "Failed to load settings" : "Fejl ved indlæsning af indstillinger",
    "This URL is already bookmarked! Overwrite?" : "Denne URL har allerede et bogmærke. Overskriv?",
    "Enter bookmark title" : "Angiv titel på bogmærke",
    "Enter bookmark URL" : "Indtast bogmærke-URL",
    "Folder" : "Mappe",
    "Root Folder" : "Rodmappe",
    "Save" : "Gem",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Netværksadgang er deaktiveret som standard. Gå til administratorindstillinger for bogmærke-appen for at tillade hentning af forhåndsvisninger og favicons.",
    "What" : "Hvad",
    "Failed to count unavailable bookmarks" : "Kunne ikke tælle utilgængelige bogmærker",
    "Failed to count archived bookmarks" : "Kunne ikke tælle arkiverede bogmærker",
    "Failed to count duplicated bookmarks" : "Kunne ikke tælle duplikerede bogmærker",
    "Failed to load bookmark" : "Bogmærket kunne ikke indlæses",
    "Failed to find existing bookmark" : "Kunne ikke finde eksisterende bogmærke",
    "Failed to create bookmark" : "Kunne ikke oprette bogmærke",
    "Failed to save bookmark" : "Kunne ikke gemme bogmærke",
    "Failed to move bookmark" : "Kunne ikke flytte bogmærke",
    "Failed to copy bookmark" : "Bogmærket kunne ikke kopieres",
    "Failed to delete bookmark" : "Kunne ikke slette bogmærke",
    "Failed to rename tag" : "Tagget kunne ikke omdøbes",
    "Failed to load tags" : "Kunne ikke indlæse tags.",
    "Failed to load folders" : "Fejl ved indlæsning af mapper",
    "Failed to delete folder" : "Fejl ved sletning af mappe",
    "Failed to create folder" : "Fejl ved opretning af mappe",
    "Failed to fetch bookmarks." : "Fejl ved indlæsning af bogmærker.",
    "Failed to load setting {key}" : "Indstillingen {key} kunne ikke indlæses",
    "Failed to update share {shareId}" : "Kunne ikke opdatere share {shareId}",
    "Failed to delete share {shareId}" : "Kunne ikke slette share {shareId}",
    "Create bookmarks for mentioned links" : "Opret bogmærker til nævnte links",
    "No links found in this message" : "Ingen links fundet i denne besked",
    "Bookmarks feed" : "Bogmærkestrøm"
},
"nplurals=2; plural=(n != 1);");
