OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Favoritos",
    "You bookmarked \"%s\"" : "Você favoritou \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s favoritou \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Alguém favoritou \"%s\"",
    "You deleted \"%s\"" : "Você excluiu \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s excluídos \"%2$s\"",
    "Someone deleted \"%s\"" : "Alguém excluiu \"%s\"",
    "You created folder \"%s\"" : "Você criou a pasta \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s criou a pasta \"%2$s\"",
    "Someone created folder \"%s\"" : "Alguém criou a pasta \"%s\"",
    "You moved folder \"%s\"" : "Você moveu a pasta \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s moveu a pasta \"%2$s\"",
    "Someone moved folder \"%s\"" : "Alguém moveu a pasta \"%s\"",
    "You deleted folder \"%s\"" : "Você excluiu a pasta \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s excluiu a pasta \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Alguém excluiu a pasta \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Você compartilhou a pasta \"%1$s\" com %2$s",
    "You shared folder \"%s\" with someone" : "Você compartilhou a pasta \"%s\" com alguém",
    "%1$s shared folder \"%2$s\" with you" : "%1$s compartilhou a pasta \"%2$s\" com você",
    "Someone shared folder \"%s\" with you" : "Alguém compartilhou a pasta \"%s\" com você",
    "You unshared folder \"%1$s\" with %2$s" : "Você removeu o compartilhamento da pasta \"%1$s\" com %2$s",
    "You unshared folder \"%s\" with someone" : "Você removeu o compartilhamento da pasta \"%s\" com alguém",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s removeu o compartilhamento da pasta \"%2$s\" com você",
    "Someone unshared folder \"%s\" with you" : "Alguém removeu o compartilhamento da pasta \"%s\" com você",
    "No file provided for import" : "Nenhum arquivo para importar",
    "Failed to upload file" : "Falha ao enviar o arquivo ",
    "Unsupported file type for import: " : "Tipo de arquivo não suportado para importação:",
    "Bookmarks shared by %s" : "Favoritos compartilhados por %s",
    "Frequent bookmarks" : "Favoritos frequentes ",
    "Recent bookmarks" : "Favoritos recentes",
    "Bookmark" : "Favorito",
    "Bookmark deleted" : "Favorito excluído",
    "Bookmark created" : "Favorito criado",
    "Bookmark moved" : "Favorito movido",
    "Bookmark updated" : "Favorito atualizado",
    "Create bookmark" : "Criar favorito",
    "Takes a link and adds it to your collection of bookmarks." : "Pega um link e o adiciona à sua coleção de favoritos.",
    "Bookmarks Backups" : "Backups de Marcadores",
    "Collect and manage bookmarks, synced with all your devices" : "Colete e gerencie favoritos, sincronizados com todos os seus dispositivos",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users and via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Classifique os favoritos em pastas\n- 🏷 Adicione etiquetas e notas pessoais\n- ☠ Encontre links quebrados e duplicados\n- 📲 Sincronize com todos os seus navegadores e dispositivos\n- 📔 Armazene versões arquivadas de seus links caso eles sejam despublicados\n- 🔍 Pesquisa de texto completo no conteúdo do site\n- 👪 Compartilhe favoritos com outros usuários e por meio de links públicos\n- ⚛ Gere feeds RSS de suas coleções\n- 📈 Estatísticas sobre a frequência com que você acessa quais links\n- 🔒 Backups automáticos da sua coleção de favoritos\n- 💼 Widgets de painel integrados para links frequentes e recentes\n\nRequirementos:\n - PHP extensões:\n   - intl: *\n   - mbstring: *\n - ao usar MySQL, use pelo menos v8.0",
    "Enter new title" : "Digite o novo título",
    "Select bookmark" : "Selecionar marcador",
    "You have never clicked this link" : "Você nunca clicou neste link",
    "You have clicked this link {count} times" : "Você clicou neste link {count} vezes",
    "Details" : "Detalhes",
    "Rename" : "Renomear",
    "Copy link" : "Copiar link",
    "Move" : "Mover",
    "Add to folders" : "Adicionar às pastas",
    "Put bookmark into trash bin" : "Coloque o marcador na lixeira",
    "Restore bookmark" : "Restaurar favorito",
    "Delete bookmark permanently" : "Excluir favorito permanentemente",
    "Do you really want to delete this bookmark?" : "Deseja realmente excluir este favorito?",
    "Link copied to clipboard" : "Link copiado para a área de transferência",
    "Content pending" : "Conteúdo pendente",
    "This content is being downloaded for offline use. Please check back later." : "Este conteúdo está sendo baixado para uso offline. Por favor, volte mais tarde.",
    "Bookmarked {time} ago" : "Marcado {time} atrás",
    "Bookmarked on {date}" : "Marcado em {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Estes são seus itens excluídos. Os itens serão excluídos permanentemente após dois meses.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Os favoritos para arquivos na web, como fotos ou PDFs, serão salvos automaticamente em seus arquivos Nextcloud, para que você ainda possa encontrá-los mesmo quando o link ficar offline. ",
    "Searching in the current folder only." : "Pesquisando apenas na pasta atual.",
    "Repeat search in all folders" : "Repita a pesquisa em todas as pastas",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Os links marcados são verificados regularmente e os que não podem ser acessados são listados aqui.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Você pode compartilhar pastas de favoritos com outras pessoas. Todas as pastas compartilhadas com você são listadas aqui.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Um marcador pode estar em várias pastas ao mesmo tempo. A atualização irá atualizar todas as cópias. Todos os favoritos duplicados estão listados aqui por conveniência.",
    "Open all selected" : "Abrir todos os selecionados",
    "Move selection" : "Mover seleção",
    "Edit tags of selection" : "Editar etiquetas da seleção",
    "Delete selection" : "Excluir seleção",
    "Select all" : "Selecionar tudo",
    "Cancel selection" : "Cancelar seleção",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Selecionados {folders} pastas e {bookmarks} favoritos",
    "Do you really want to delete these items?" : "Deseja realmente excluir estes itens?",
    "Trash Bin" : "Lixeira",
    "Go back" : "Voltar",
    "Share folder" : "Compartilhar pasta",
    "Open folder details" : "Abrir detalhes da pasta",
    "Select one or more tags" : "Selecione um ou mais rótulos",
    "New" : "Novo",
    "New bookmark" : "Novo marcador",
    "New folder" : "Nova pasta",
    "Change to grid view" : "Alternar para visualização de grade",
    "Change to list view" : "Alternar para visualização em lista",
    "Copy RSS Feed of current view" : "Copiar o feed RSS da vista atual",
    "The RSS feed requires authentication with your Nextcloud credentials" : "O feed RSS requer autenticação com suas credenciais Nextcloud",
    "Search" : "Pesquisar",
    "Empty trash bin" : "Esvaziar lixeira",
    "Sort by created date" : "Ordenar por data de criação",
    "Sort by last modified" : "Ordenar por data de modificação",
    "Sort by title" : "Ordenar por título",
    "Sort by click count" : "Ordenar por quantidade de cliques",
    "Sort by manual order" : "Ordenar manualmente",
    "Sort by URL" : "Classificar por URL",
    "RSS feed copied" : "Feed RSS copiado",
    "Enter a link" : "Digite um link",
    "Enter a title" : "Digite um título",
    "No bookmarks found" : "Nenhum favorito encontrado",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} pastas e {bookmarks} favoritos",
    "Welcome to Bookmarks" : "Bem-vindo aos Favoritos",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Este aplicativo permite que você gerencie links para seus lugares favoritos na web. Classifique seus favoritos em pastas, rotule-os com tags e compartilhe-os com outras pessoas! O aplicativo verificará regularmente a disponibilidade de todos os seus links e exibirá os links indisponíveis. Se você adicionar um link para um arquivo na web, o arquivo será baixado automaticamente para seus arquivos Nextcloud. Você também pode importar favoritos exportados de outros serviços ou sincronizar favoritos diretamente de todos os seus navegadores com este aplicativo.",
    "Add a bookmark" : "Adicionar favorito",
    "Import bookmarks" : "Importar favoritos",
    "Sync with your browser" : "Sincronizar com seu navegador",
    "Select folder" : "Selecionar pasta",
    "Enter folder title" : "Digite o título da pasta",
    "Shared by {user}" : "Compartilhado por {user}",
    "Rename folder" : "Renomear pasta",
    "Move folder" : "Mover pasta",
    "Put folder into trashbin" : "Colocar pasta na lixeira",
    "Restore folder" : "Restaurar pasta",
    "Delete folder permanently" : "Excluir pasta permanentemente",
    "Do you really want to permanently delete this folder?" : "Você realmente deseja excluir esta pasta permanentemente?",
    "Choose folder" : "Escolher pasta",
    "Submit" : "Enviar",
    "Cancel" : "Cancelar",
    "Deleting bookmarks" : "Excluindo favoritos",
    "Deleting selection" : "Excluindo seleção",
    "Importing bookmarks" : "Importando favoritos",
    "Moving selection" : "Movendo seleção",
    "Adding selection to folders" : "Adicionando seleção a pastas",
    "Emptying trashbin" : "Esvaziando lixeira",
    "All bookmarks" : "Todos os favoritos",
    "Recent" : "Recente",
    "Shared with you" : "Compartilhado com você",
    "Files" : "Arquivos",
    "Duplicates" : "Duplicatas",
    "Broken links" : "Links inválidos",
    "New tag" : "Nova tag",
    "Search tags" : "Tags de busca",
    "Delete" : "Excluir",
    "Untagged" : "Sem rótulos",
    "{used} bookmarks of {available} available" : "{used} favoritos de {available} disponíveis",
    "Bookmarks Settings" : "Configurações de favoritos",
    "No bookmarked files" : "Sem arquivos favoritados",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Os favoritos para arquivos como fotos ou PDFs serão salvos automaticamente em seus arquivos do Nextcloud, para que você possa encontrá-los mesmo quando o link ficar offline.",
    "Nothing found" : "Nada encontrado",
    "Your search yielded no results in the current folder." : "Sua pesquisa não produziu resultados na pasta atual.",
    "No broken links" : "Sem links quebrados",
    "No shared folders" : "Nenhuma pasta compartilhada",
    "No duplicated bookmarks" : "Nenhum marcador duplicado",
    "No deleted bookmarks" : "Nenhum favorito excluído",
    "You haven't deleted anything yet." : "Você ainda não excluiu nada.",
    "No bookmarks here" : "Sem favoritos aqui",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Adicione marcadores manualmente ou importe marcadores de um arquivo HTML.",
    "Bookmarks settings" : "Configurações de favoritos",
    "Import/Export" : "Importar/Exportar",
    "Export bookmarks" : "Exportar favoritos",
    "Auto-archiving" : "Arquivamento automático",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "O aplicativo de favoritos pode arquivar automaticamente o conteúdo da web dos links que você marcou",
    "Enable archiving" : "Habilitar arquivamento",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Digite o caminho de uma pasta em seus Arquivos onde os arquivos marcados devem ser armazenados. ",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Atualmente, seu administrador desativou o acesso à rede para este aplicativo, e é por isso que o arquivamento automático está desativado no momento.",
    "Auto-Backup" : "Backup automático",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "O aplicativo de favoritos pode fazer backup automático de seus favoritos diariamente para evitar perda de dados ao sincronizar favoritos entre dispositivos.",
    "Enable backups" : "Habilitar backups",
    "Enter the path of a folder in your Files where backups will be stored." : "Digite o caminho de uma pasta em seus Arquivos onde os backups serão armazenados.",
    "Client apps" : "Aplicativos cliente",
    "Also check out the collection of client apps that integrate with this app: " : "Verifique também a coleção de aplicativos cliente que se integram a este aplicativo:",
    "Install web app" : "Instalar aplicativo da web",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Você pode instalar este app na tela inicial dos seus dispositivos para rapidamente acessar os favoritos em seu celular. Você pode facilmente remover o app de sua tela inicial, se você não gostar dele.",
    "Install on home screen" : "Instalar na tela inicial",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Arraste-o para os favoritos do seu navegador e clique nele para adicionar rapidamente uma página da web aos favoritos. ",
    "Add to {instanceName}" : "Adicionar em {instanceName}",
    "Need help?" : "Precisa de ajuda?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Se você tiver problemas com este aplicativo de Favoritos ou tiver alguma ideia do que pode ser melhorado, não hesite em entrar em contato clicando aqui.",
    "Support this project" : "Apoie este projeto",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Meu trabalho neste aplicativo de favoritos é alimentado por um modelo de assinatura voluntária. Se você acha que o que faço vale a pena, ficaria feliz se você pudesse apoiar meu trabalho. Além disso, considere fazer uma avaliação do aplicativo na loja de aplicativos Nextcloud. Obrigado 💙 ",
    "Archive path" : "Caminho do arquivamento",
    "Backup path" : "Caminho do backup",
    "Please select \"Add to home screen\" in your browser menu" : "Selecione \"Adicionar à tela inicial\" no menu do navegador",
    "(Empty title)" : "(Título vazio)",
    "Title" : "Título",
    "Link" : "Link",
    "Untitled folder" : "Pasta sem título",
    "Root folder" : "Pasta raiz",
    "Tags" : "Etiquetas",
    "Select tags and create new ones" : "Selecionar tags e criar novas",
    "Notes" : "Anotações",
    "Notes for this bookmark …" : "Notas para este favorito…",
    "Archived file" : "Arquivo arquivado",
    "Download file" : "Baixar arquivo",
    "Open file location" : "Abrir local do arquivo",
    "Created {time} ago" : "Criado há {time}",
    "Created on {date}" : "Criado em {date}",
    "Owner" : "Proprietário",
    "Sharing" : "Compartilhando",
    "Select a user or group" : "Selecionar um usuário ou grupo",
    "Share link" : "Link de compartilhamento",
    "Reading allowed" : "Leitura permitida",
    "Copy RSS feed" : "Copiar feed RSS",
    "Delete link" : "Excluir link",
    "Create public link" : "Criar link público",
    "Resharing allowed" : "Recompartilhamento permitido",
    "Editing allowed" : "Edição permitida",
    "Allow editing" : "Permitir edição",
    "Allow resharing" : "Permitir recompartilhamento",
    "Remove share" : "Excluir compartilhamento",
    "Link copied" : "Link copiado",
    "Privacy" : "Privacidade",
    "The app will try to access web pages that you add to automatically add information about them." : "O aplicativo tentará acessar as páginas da web que você adicionar para adicionar automaticamente informações sobre elas.",
    "Enable accessing and collecting information from the web pages you add" : "Ative o acesso e coleta de informações das páginas web que você adicionar",
    "Performance" : "Desempenho",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Em uma instalação com muitos usuários, pode ser útil restringir o número de favoritos por conta.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Número máximo permitido de favoritos por conta. (0 para sem limite; o padrão é sem limite)",
    "Previews" : "Prévias",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "Para exibir capturas de tela reais de seus sites favoritos, o aplicativo pode usar serviços de terceiros para gerar visualizações.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Você pode  inscrever-se gratuitamente em screeenly.com ou configurar seu próprio servidor.",
    "Screeenly API URL" : "URL da API do Screeenly",
    "Screeenly API key" : "Chave da API do Screeenly",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Chave da API ScreenshotMachine",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL da API do Webshot",
    "Generic screenshot API" : "API genérica de captura de tela",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Cadastre-se em qualquer um dos provedores de API de captura de tela e coloque a URL da API abaixo. Use a variável {url} como espaço reservado para a URL da captura de tela. A API deve retornar apenas a imagem diretamente.",
    "Generic API URL" : "URL genérico da API",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Basta instalar o Pageres CLI de Sindre Sorhus em seu servidor e os Bookmarks o encontrarão. Você ainda pode adicionar vars ENV adicionais para serem alimentados em pageres, por exemplo. conforme indicado no espaço reservado:",
    "Pageres ENV variables" : "Variáveis de ENV do Pageres",
    "Failed to save settings" : "Erro ao salvar configurações",
    "Failed to load settings" : "Erro ao carregar configurações",
    "This URL is already bookmarked! Overwrite?" : "Esta URL já está nos seus favoritos. Sobrescrever?",
    "Enter bookmark title" : "Digite o título do favorito",
    "Enter bookmark URL" : "Digite a URL do favorito",
    "Folder" : "Pasta",
    "Root Folder" : "Pasta raiz",
    "Save" : "Salvar",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "O acesso a rede é desabilitado por padrão. Vá nas configurações administrativas do aplicativo favoritos para permitir a alocação de prévias e favicons.",
    "What's new?" : "O que há de novo?",
    "Leave a rating on the Nextcloud App Store" : "Deixe uma avaliação na Nextcloud App Store",
    "What" : "O que",
    "Failed to count unavailable bookmarks" : "Erro ao contar os favoritos indisponíveis",
    "Failed to count archived bookmarks" : "Erro ao contar os favoritos arquivados",
    "Failed to count duplicated bookmarks" : "Falha ao contar favoritos duplicados",
    "Failed to load bookmark" : "Não foi possível carregar o favorito",
    "Failed to find existing bookmark" : "Erro ao encontrar um favorito existente",
    "Failed to create bookmark" : "Erro ao criar favorito",
    "Failed to save bookmark" : "Erro ao salvar favorito",
    "Failed to move bookmark" : "Erro ao mover favorito",
    "Failed to copy bookmark" : "Falha ao copiar o favorito",
    "Failed to delete bookmark" : "Erro ao excluir favorito",
    "Failed to rename tag" : "Erro ao renomear etiqueta",
    "Failed to load tags" : "Erro ao carregar rótulos",
    "Failed to load folders" : "Erro ao carregar pastas",
    "Failed to load deleted folders" : "Falha ao carregar pastas excluídas",
    "Failed to load deleted bookmarks" : "Falha ao carregar favoritos excluídos",
    "Failed to delete folder" : "Erro ao excluir pasta",
    "Failed to move folder" : "Falha ao mover a pasta",
    "Failed to create folder" : "Erro ao criar pasta",
    "Failed to fetch bookmarks." : "Erro ao buscar favoritos.",
    "Failed to store setting" : "Falha ao armazenar configuração",
    "Failed to load setting {key}" : "Erro ao carregar a configuração {key}",
    "Failed to update share {shareId}" : "Erro ao atualizar o compartilhamento {shareId}",
    "Failed to delete share {shareId}" : "Erro ao excluir o compartilhamento {shareId}",
    "Create bookmarks for mentioned links" : "Crie marcadores para links mencionados",
    "No links found in this message" : "Nenhum link encontrado nesta mensagem",
    "Bookmarks feed" : "Feed de favoritos"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
