OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Üksikasjad",
    "Rename" : "Nimeta ümber",
    "Copy link" : "Kopeeri link",
    "Move" : "Liiguta",
    "Delete selection" : "Kustuta valik",
    "Select all" : "Vali kõik",
    "Go back" : "Mine tagasi",
    "New" : "Uus",
    "New folder" : "Uus kaust",
    "Search" : "Otsi",
    "Empty trash bin" : "Tühjenda prügikast",
    "Rename folder" : "Nimeta kaust ümber",
    "Choose folder" : "Vali kaust",
    "Submit" : "Saada",
    "Cancel" : "Loobu",
    "Recent" : "Hiljutised",
    "Shared with you" : "Sinuga jagatud",
    "Files" : "Failid",
    "Delete" : "Kustuta",
    "Need help?" : "Vajad abi?",
    "Title" : "Pealkiri",
    "Link" : "Link",
    "Tags" : "Sildid",
    "Notes" : "Märkmed",
    "Download file" : "Lae fail alla",
    "Owner" : "Omanik",
    "Sharing" : "Jagamine",
    "Share link" : "Jaga link",
    "Allow editing" : "Luba muutmine",
    "Allow resharing" : "Luba edasijagamine",
    "Link copied" : "Link kopeeritud",
    "Privacy" : "Privaatsus",
    "Folder" : "Kaust",
    "Save" : "Salvesta",
    "Failed to delete bookmark" : "Järjehoidja kustutamine ebaõnnestus",
    "Failed to delete folder" : "Kausta kustutamine ebaõnnestus"
},
"nplurals=2; plural=(n != 1);");
