OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bókamerki",
    "No file provided for import" : "Engin skrá valin til innflutnings",
    "Bookmarks shared by %s" : "Bókamerki deilt af %s",
    "Select bookmark" : "Veldu bókamerki",
    "Details" : "Nánar",
    "Rename" : "Endurnefna",
    "Copy link" : "Afrita tengil",
    "Move" : "Færa",
    "Link copied to clipboard" : "Tengill afritaður á klippispjald",
    "Open all selected" : "Opna allt valið",
    "Move selection" : "Færa valið",
    "Delete selection" : "Eyða vali",
    "Select all" : "Select all",
    "Cancel selection" : "Hætta við val",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Valdar {folders} möppur og {bookmarks} bókamerki",
    "Go back" : "Fara til baka",
    "Select one or more tags" : "Veldu eitt eða fleiri merki",
    "New" : "Nýtt",
    "New bookmark" : "Nýtt bókamerki",
    "New folder" : "Ný mappa",
    "Search" : "Search",
    "Empty trash bin" : "Tæma ruslið",
    "Sort by created date" : "Sort by created date",
    "RSS feed copied" : "RSS-fréttastreymi afritað",
    "Enter a link" : "Settu inn slóð",
    "Add a bookmark" : "Bæta við bókamerki",
    "Select folder" : "Veldu möppu",
    "Enter folder title" : "Settu inn heiti möppu",
    "Shared by {user}" : "Deilt af {user}",
    "Rename folder" : "Endurnefna möppu",
    "Choose folder" : "Veldu möppu",
    "Submit" : "Senda inn",
    "Cancel" : "Hætta við",
    "All bookmarks" : "Öll bókamerki",
    "Recent" : "Nýlegt",
    "Shared with you" : "Deilt með þér",
    "Files" : "Skrár",
    "Delete" : "Eyða",
    "Untagged" : "Ómerkt",
    "{used} bookmarks of {available} available" : "{used} bókamerki af {available} tiltækum",
    "No bookmarks here" : "Engin bókamerki hér",
    "Client apps" : "Biðlaraforrit",
    "Also check out the collection of client apps that integrate with this app: " : "Skoðaðu einnig úrval þeirra biðlaraforrita sem samþættast þessu forriti:",
    "Bookmarklet" : "Bókamerklingur",
    "Add to {instanceName}" : "Bæta við {instanceName}",
    "Need help?" : "Þarftu hjálp?",
    "Title" : "Titill",
    "Link" : "Tengill",
    "Root folder" : "Rótarmappa",
    "Tags" : "Merki",
    "Notes" : "Minnispunktar",
    "Download file" : "Sækja skrá",
    "Owner" : "Eigandi",
    "Sharing" : "Deiling",
    "Select a user or group" : "Veldu notanda eða hóp",
    "Share link" : "Deila tengli",
    "Copy RSS feed" : "Afrita RSS-fréttastreymi",
    "Delete link" : "Eyða tengli",
    "Create public link" : "Búa til opinberan tengil",
    "Allow editing" : "Leyfa breytingar",
    "Allow resharing" : "Leyfa endurdeilingu",
    "Remove share" : "Fjarlægja sameign",
    "Link copied" : "Tengill afritaður",
    "Privacy" : "Gagnaleynd",
    "Enable accessing and collecting information from the web pages you add" : "Virkja aðgang og söfnun upplýsinga af vefsíðunum sem þú bætir við",
    "Performance" : "Afköst",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Leyfður hámarksföldi bókamerkja á hvern notandaaðgang. (0 fyrir engin takmörk; það er sjálfgefið)",
    "Previews" : "Forskoðun",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Þú getur annað hvort skráð þig ókeypis á  screeenly.com eða sett upp þinn eigin þjón.",
    "Screeenly API URL" : "Slóð á API-forritsviðmót Screenly",
    "Screeenly API key" : "Screeenly API-lykill",
    "Failed to save settings" : "Mistókst að vista stillingar",
    "Failed to load settings" : "Mistókst að hlaða inn stillingum",
    "This URL is already bookmarked! Overwrite?" : "Þessi slóð er þegar bókamerkt! Skrifa yfir?",
    "Enter bookmark title" : "Settu inn titil á bókamerki",
    "Enter bookmark URL" : "Settu inn slóð á bókamerki",
    "Folder" : "Mappa",
    "Root Folder" : "Rótarmappa",
    "Save" : "Vista",
    "What's new?" : "Hvað er nýtt á döfinni?",
    "Failed to find existing bookmark" : "Mistókst að finna fyrirliggjandi bókamerki",
    "Failed to create bookmark" : "Mistókst að búa til bókamerki",
    "Failed to save bookmark" : "Mistókst að vista bókamerki",
    "Failed to move bookmark" : "Mistókst að færa bókamerki",
    "Failed to delete bookmark" : "Mistókst að eyða bókamerki",
    "Failed to load tags" : "Mistókst að hlaða inn merkjum",
    "Failed to load folders" : "Mistókst að hlaða inn möppum",
    "Failed to delete folder" : "Mistókst að eyða möppu",
    "Failed to create folder" : "Mistókst að búa til möppu",
    "Failed to fetch bookmarks." : "Ekki tókst að sækja bókamerki.",
    "Failed to load setting {key}" : "Mistókst að hlaða inn {key} stillingunni",
    "Failed to update share {shareId}" : "Mistókst að uppfæra sameignina {shareId}",
    "Failed to delete share {shareId}" : "Mistókst að eyða sameigninni {shareId}",
    "Bookmarks feed" : "Bókamerkjastreymi"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
