OC.L10N.register(
    "bookmarks",
    {
    "Details" : "ລາຍລະອຽດ",
    "Rename" : "ປ່ຽນຊື່",
    "Copy link" : "ສຳເນົາລິງ",
    "Move" : "ຍ້າຍ",
    "Select all" : "ເລືອກທັງໝົດ",
    "New folder" : "ໂຟນເດີໃຫມ່",
    "Search" : "ຄົ້ນຫາ",
    "Empty trash bin" : "ລ້າງຖັງຂີ້ເຫຍື່ອ",
    "Sort by created date" : "ຈັດລຽງຕາມລຳດັບວັນທີສ້າງ",
    "Rename folder" : "ປ່ຽນຊືໂຟນເດີ",
    "Cancel" : "ຍົກເລີກ",
    "Recent" : "ຫວ່າງບໍ່ດົນມາ ນີ້",
    "Shared with you" : "ແບ່ງປັບກັບທ່ານ",
    "Files" : "ຟາຍ",
    "Delete" : "ລຶບ",
    "Need help?" : "ຕ້ອງການຄວາມຊ່ວຍເຫຼືອ?",
    "Link" : "ລິງ",
    "Tags" : "ປ້າຍກຳກັບ",
    "Download file" : "ດາວ ໂຫລດຟາຍ",
    "Owner" : "ເຈົ້າຂອງ",
    "Sharing" : "ການແບ່ງປັນ",
    "Share link" : "ແບ່ງປັນລິງ",
    "Allow editing" : "ອະນຸຍາດໃຫ້ ແກ້ ໄຂໄດ້",
    "Allow resharing" : "ອະນຸຍາດໃຫ້ ການແບ່ງປັນຄືນ",
    "Link copied" : "ສຳເນົາລິງ",
    "Privacy" : "ສ່ວນຕົວ",
    "Folder" : "ໂຟນເດີ",
    "Save" : "ບັນທຶກ"
},
"nplurals=1; plural=0;");
