OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "书签",
    "You bookmarked \"%s\"" : "您添加了书签 \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s 添加了书签 \"%2$s\"",
    "Someone bookmarked \"%s\"" : "有人添加了书签 \"%s\"",
    "You deleted \"%s\"" : "您删除了 \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s 删除了 \"%2$s\"",
    "Someone deleted \"%s\"" : "有人删除了 \"%s\"",
    "You created folder \"%s\"" : "您已创建文件夹 \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s已创建文件夹 \"%2$s\"",
    "Someone created folder \"%s\"" : "有人已创建文件夹 \"%s\"",
    "You moved folder \"%s\"" : "您已移动文件夹 \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s 已移动文件夹 \"%2$s\"",
    "Someone moved folder \"%s\"" : "有人已移动文件夹 \"%s\"",
    "You deleted folder \"%s\"" : "您已删除文件夹 \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s 已删除文件夹 \"%2$s\"",
    "Someone deleted folder \"%s\"" : "有人已删除文件夹 \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "您已将文件夹 \"%1$s\" 共享给 %2$s",
    "You shared folder \"%s\" with someone" : "您已将文件夹 \"%s\" 共享给其他人",
    "%1$s shared folder \"%2$s\" with you" : "%1$s已共享文件夹 \"%2$s\" 给您",
    "Someone shared folder \"%s\" with you" : "有人共享文件夹 \"%s\" 给您",
    "You unshared folder \"%1$s\" with %2$s" : "您已取消开放给 %2$s的%1$s文件夹共享",
    "You unshared folder \"%s\" with someone" : "您已取消%s文件夹的共享",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s取消了开放给您的%2$s文件夹共享",
    "Someone unshared folder \"%s\" with you" : "有人取消了开放给您的%s文件夹共享",
    "No file provided for import" : "未提供导入文件",
    "Failed to upload file" : "上传文件失败",
    "Bookmarks shared by %s" : "由 %s 共享的书签",
    "Frequent bookmarks" : "常用书签",
    "Recent bookmarks" : "近期书签",
    "Bookmark" : "书签",
    "Bookmark deleted" : "书签已删除",
    "Bookmark created" : "书签已创建",
    "Bookmark moved" : "书签已移除",
    "Bookmark updated" : "书签已更新",
    "Create bookmark" : "创建书签",
    "Takes a link and adds it to your collection of bookmarks." : "获取一个链接并将其添加到您的书签中。",
    "Bookmarks Backups" : "书签备份",
    "Enter new title" : "输入新标题",
    "Select bookmark" : "选择书签",
    "Details" : "详情",
    "Rename" : "重命名",
    "Copy link" : "复制链接",
    "Move" : "移动",
    "Add to folders" : "添加到文件夹",
    "Do you really want to delete this bookmark?" : "你真想删除这个书签吗？",
    "Link copied to clipboard" : "链接已复制到剪贴板",
    "Content pending" : "内容待定",
    "This content is being downloaded for offline use. Please check back later." : "此内容正被下载以供离线使用。请稍后再来查看。 ",
    "Bookmarked {time} ago" : "{time} 前加入书签",
    "Bookmarked on {date}" : "于 {date} 加入书签",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "网络上的文件，类似照片或 PDF 等的书签会被自动保存到你的Nextcloud 文件中，这样即使链接的文件消失，你仍然可以找到它们。",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "已添加书签的链接会定期检查，无法访问的链接会显示在这里",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "您可以与其他人分享书签文件夹。所有与您分享的文件夹会显示在这里。",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "一个书签可以同时在多个文件夹中。更新它将会更新所有副本。为了方便起见，这里列出了所有重复的书签。",
    "Open all selected" : "打开所选",
    "Move selection" : "移动选择项",
    "Edit tags of selection" : "编辑选中的标签",
    "Delete selection" : "删除选择项",
    "Select all" : "全部选择",
    "Cancel selection" : "取消选择",
    "Selected {folders} folders and {bookmarks} bookmarks" : "已选择文件夹 {folders} 和书签 {bookmarks} ",
    "Do you really want to delete these items?" : "你真想删除这些项目吗？",
    "Go back" : "返回",
    "Share folder" : "分享文件夹",
    "Select one or more tags" : "选择一个或多个标签",
    "New" : "新建",
    "New bookmark" : "新建书签",
    "New folder" : "新建文件夹",
    "Change to grid view" : "变为网格视图",
    "Change to list view" : "变为列表视图",
    "Copy RSS Feed of current view" : "复制当前视图的 RSS 订阅源",
    "The RSS feed requires authentication with your Nextcloud credentials" : "此 RSS 订阅源需要使用 Nextcloud 凭据进行身份验证",
    "Search" : "搜索",
    "Empty trash bin" : "清空回收站",
    "Sort by created date" : "按创建日期排序 ",
    "Sort by last modified" : "按最后更改排序",
    "Sort by title" : "按标题排序",
    "Sort by click count" : "按点击数排序",
    "Sort by manual order" : "按手动顺序排序",
    "Sort by URL" : "按 URL 排序",
    "RSS feed copied" : "RSS提要已复制",
    "Enter a link" : "输入一个链接",
    "Enter a title" : "输入标题",
    "No bookmarks found" : "未找到书签",
    "{folders} folders and {bookmarks} bookmarks" : "{folders}个文件夹和{bookmarks}枚书签",
    "Welcome to Bookmarks" : "欢迎使用书签",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "此应用程序让你可以管理网络上您喜爱之处的链接。将您的书签整理到文件夹中，用标签标记，以及与其他人分享它们！应用程序会定期检查您所有链接的可用性，并显示无法使用的链接。如果您添加一个指向在线文件的链接，文件将会自动下载到您的文件中。您还可以导入从其他服务导出的书签，或是直接从您的所有浏览器中的书签同步到此应用程序。",
    "Add a bookmark" : "添加书签",
    "Import bookmarks" : "导入标签",
    "Sync with your browser" : "与你的浏览器同步",
    "Select folder" : "选择文件夹",
    "Enter folder title" : "输入文件夹标题",
    "Shared by {user}" : "由{user} 共享",
    "Rename folder" : "重命名文件夹",
    "Move folder" : "移动文件夹",
    "Choose folder" : "选择文件夹",
    "Submit" : "提交",
    "Cancel" : "取消",
    "Deleting bookmarks" : "正在删除书签",
    "Deleting selection" : "正在删除选定的对象",
    "Importing bookmarks" : "正在导入书签",
    "Moving selection" : "正在移动所选对象",
    "Adding selection to folders" : "添加选中项到文件夹",
    "All bookmarks" : "全部书签",
    "Recent" : "最近",
    "Shared with you" : "已共享给您",
    "Files" : "文件",
    "Duplicates" : "重复",
    "Broken links" : "失效的链接",
    "New tag" : "新标签",
    "Search tags" : "搜索标签",
    "Delete" : "删除",
    "Untagged" : "未标记的",
    "{used} bookmarks of {available} available" : " {available}书签可用，已用{used}",
    "No bookmarked files" : "无已添加书签的文件",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或PDF等文件的书签会被自动保存到你的Nextcloud文件中，因此即使链接离线，你仍然可以找到它们。",
    "No broken links" : "没有失效的链接",
    "No shared folders" : "没有共享的文件夹",
    "No duplicated bookmarks" : "没有重复的书签",
    "No bookmarks here" : "无书签",
    "Add bookmarks manually or import bookmarks from a HTML file." : "手动添加书签或从HTML文件中导入书签。",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "输入一个文件夹路径，加书签的文件会被存储至该文件夹",
    "Enter the path of a folder in your Files where backups will be stored." : "输入一个存储备份的文件夹的路径。",
    "Client apps" : "客户端应用",
    "Also check out the collection of client apps that integrate with this app: " : "还可以查看与此应用集成的客户端应用集合：",
    "Install web app" : "安装Web应用",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "你可以在你的设备主屏幕上安装这个应用程序来快速访问你手机上的书签。如果你不喜欢它，你可以很容易地从主屏幕上删除它。",
    "Install on home screen" : "安装到主屏幕",
    "Bookmarklet" : "小书签",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "将此拖到浏览器书签中，并单击它可快速将网页添加为书签。",
    "Add to {instanceName}" : "添加到 {instanceName}",
    "Need help?" : "需要帮助？",
    "Archive path" : "归档路径",
    "Backup path" : "备份路径",
    "Please select \"Add to home screen\" in your browser menu" : "请点击浏览器菜单中的“添加到主屏幕”",
    "Title" : "标题",
    "Link" : "链接",
    "Untitled folder" : "未命名文件夹",
    "Root folder" : "根文件夹",
    "Tags" : "标签",
    "Select tags and create new ones" : "选择和生成标记",
    "Notes" : "笔记",
    "Notes for this bookmark …" : "标签的注释",
    "Archived file" : "已存档的文件",
    "Download file" : "下载文件",
    "Open file location" : "打开文件位置 ",
    "Created {time} ago" : "创建于 {time} 之前",
    "Created on {date}" : "创建于 {date}",
    "Owner" : "所有者",
    "Sharing" : "正在共享",
    "Select a user or group" : "选择用户或分组",
    "Share link" : "共享链接",
    "Reading allowed" : "已允许读取",
    "Copy RSS feed" : "复制RSS提要",
    "Delete link" : "删除链接",
    "Create public link" : "生成公开链接地址",
    "Resharing allowed" : "不允许重新分享 ",
    "Editing allowed" : "已允许编辑",
    "Allow editing" : "允许编辑",
    "Allow resharing" : "允许重新分享",
    "Remove share" : "移除共享",
    "Link copied" : "已复制链接",
    "Privacy" : "隐私",
    "Enable accessing and collecting information from the web pages you add" : "启用从您添加的网页访问和搜集信息的功能",
    "Performance" : "性能",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "在有很多用户的安装中，限制每个账号的书签数量可能是有用的。",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "每个账号允许的最大书签数量。（0为无限制；默认为无限制）",
    "Previews" : "预览",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "您既可以在 screeenly.com 免费注册，也可以搭建您自己的服务器。",
    "Screeenly API URL" : "Screenly API 地址",
    "Screeenly API key" : "Screenly API 密钥",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API key",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Pageres CLI" : "Pageres CLI",
    "Pageres ENV variables" : "Pageres ENV 变量",
    "Failed to save settings" : "保存设置失败",
    "Failed to load settings" : "加载设置失败",
    "This URL is already bookmarked! Overwrite?" : "此链接已加入书签！是否覆盖？",
    "Enter bookmark title" : "输入书签标题",
    "Enter bookmark URL" : "输入书签网址",
    "Folder" : "文件夹",
    "Root Folder" : "根目录",
    "Save" : "保存",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "网络访问默认关闭。进入书签应用的管理员设置，允许获取预览和书签图标。 ",
    "What's new?" : "有哪些更新？",
    "What" : "是什么",
    "Failed to count unavailable bookmarks" : "无法计算不可用的书签",
    "Failed to count archived bookmarks" : "无法计算归档的书签",
    "Failed to count duplicated bookmarks" : "计算重复的书签失败",
    "Failed to load bookmark" : "载入标签失败",
    "Failed to find existing bookmark" : "无法找到已有书签",
    "Failed to create bookmark" : "创建书签失败",
    "Failed to save bookmark" : "保存书签失败",
    "Failed to move bookmark" : "移动书签失败",
    "Failed to copy bookmark" : "复制书签失败",
    "Failed to delete bookmark" : "删除书签失败",
    "Failed to rename tag" : "重命名标记失败",
    "Failed to load tags" : "加载标签失败",
    "Failed to load folders" : "加载文件夹失败",
    "Failed to delete folder" : "删除文件夹失败",
    "Failed to create folder" : "创建文件夹失败",
    "Failed to fetch bookmarks." : "获取书签失败",
    "Failed to load setting {key}" : "加载设置{key}失败",
    "Failed to update share {shareId}" : "更新共享{shareId}失败",
    "Failed to delete share {shareId}" : "删除共享{shareId}失败",
    "Create bookmarks for mentioned links" : "为提到的链接创建书签",
    "No links found in this message" : "消息中没有找到链接",
    "Bookmarks feed" : "书签订阅源"
},
"nplurals=1; plural=0;");
