OC.L10N.register(
    "bookmarks",
    {
    "Rename" : "Rename",
    "Move" : "Move",
    "Search" : "Search",
    "Cancel" : "Cancel",
    "Shared with you" : "Shared with you",
    "Files" : "Файлы",
    "Delete" : "Delete",
    "Title" : "Title",
    "Link" : "Link",
    "Notes" : "Notes",
    "Owner" : "Owner",
    "Share link" : "Share link",
    "Allow editing" : "Дазволіць рэдагаванне",
    "Folder" : "Folder",
    "Save" : "Save"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
