OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Könyvjelzők",
    "You bookmarked \"%s\"" : "Elmentve a könyvjelzők közé: „%s”",
    "%1$s bookmarked \"%2$s\"" : "%1$s könyvjelzőzte ezt: „%2$s”",
    "Someone bookmarked \"%s\"" : "Valaki már könyvjelzőzte ezt: „%s”",
    "You deleted \"%s\"" : "„%s” törölve",
    "%1$s deleted \"%2$s\"" : "%1$s törölte ezt: „%2$s”",
    "Someone deleted \"%s\"" : "Valaki törölte ezt: „%s”",
    "You created folder \"%s\"" : "Létrehozta ezt a mappát: „%s”",
    "%1$s created folder \"%2$s\"" : "%1$s létrehozta a következő mappát: „%2$s”",
    "Someone created folder \"%s\"" : "Valaki létrehozta ezt a mappát: „%s”.",
    "You moved folder \"%s\"" : "Áthelyezte ezt a mappát: „%s”",
    "%1$s moved folder \"%2$s\"" : "%1$s áthelyezte ezt a mappát: „%2$s”",
    "Someone moved folder \"%s\"" : "Valaki áthelyezte ezt a mappát: „%s”",
    "You deleted folder \"%s\"" : "Törölte ezt a mappát: %s.",
    "%1$s deleted folder \"%2$s\"" : "%1$s törölte ezt a mappát: „%2$s”",
    "Someone deleted folder \"%s\"" : "Valaki törölte ezt a mappát: „%s”.",
    "You shared folder \"%1$s\" with %2$s" : "Megosztotta a(z) „%1$s mappát vele: %2$s",
    "You shared folder \"%s\" with someone" : "Megosztotta a(z) „%s” mappát valakivel",
    "%1$s shared folder \"%2$s\" with you" : "%1$s megosztotta Önnel a(z) „%2$s” mappát",
    "Someone shared folder \"%s\" with you" : "Valaki megosztotta Önnel a(z) „%s” mappát",
    "You unshared folder \"%1$s\" with %2$s" : "Megszüntette a(z) „%1$s” mappa megosztását vele: %2$s",
    "You unshared folder \"%s\" with someone" : "Megszüntette a(z) „%s” mappa megosztását valakivel",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s megszüntette a(z) „%2$s” mappa megosztását Önnel",
    "Someone unshared folder \"%s\" with you" : "Valaki megszüntette a(z) „%s” mappa megosztását Önnel",
    "No file provided for import" : "Nincs fájl megadva az importáláshoz",
    "Bookmarks shared by %s" : "%s által megosztott könyvjelzők",
    "Frequent bookmarks" : "Gyakori könyvjelzők",
    "Recent bookmarks" : "Legújabb könyvjelzők",
    "Bookmark" : "Könyvjelző",
    "Bookmark deleted" : "Könyvjelző törölve",
    "Bookmark created" : "Könyvjelző létrehozva",
    "Bookmark moved" : "Könyvjelző áthelyezve",
    "Bookmark updated" : "Könyvjelző frissítve",
    "Create bookmark" : "Könyvjelző létrehozása",
    "Takes a link and adds it to your collection of bookmarks." : "Fog egy hivatkozást, és hozzáadja a könyvjelzők gyűjteményéhez.",
    "Bookmarks Backups" : "Könyvjelzők biztonsági mentése",
    "Collect and manage bookmarks, synced with all your devices" : "Könyvjelzők gyűjtése és kezelése szinkronizálva az összes eszközén",
    "Enter new title" : "Adja meg a címet",
    "Select bookmark" : "Válasszon könyvjelzőt",
    "You have never clicked this link" : "Még soha nem kattintott erre a linkre",
    "You have clicked this link {count} times" : "{count} alkalommal kattintott ezen a linken",
    "Details" : "Részletek",
    "Rename" : "Átnevezés",
    "Copy link" : "Hivatkozás másolása",
    "Move" : "Áthelyezés",
    "Add to folders" : "Hozzáadás a mappákhoz",
    "Restore bookmark" : "Könyvjelző visszaállítása",
    "Do you really want to delete this bookmark?" : "Biztos, hogy törli ezt a könyvjelzőt?",
    "Link copied to clipboard" : "Hivatkozás a vágólapra másolva",
    "Content pending" : "Tartalom függőben",
    "This content is being downloaded for offline use. Please check back later." : "Ez a tartalom offline használatra töltődik le. Nézzen vissza később.",
    "Bookmarked {time} ago" : "Könyvjelzőzve ennyi ideje: {time}",
    "Bookmarked on {date}" : "Könyvjelzőzés dátuma: {date}",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "A weben lévő fájlok, például a fényképek vagy a PDF-ek könyvjelzőit automatikusan menti az Ön Nextcloud fájljaiba, így akkor is megtalálhatja őket, ha a kapcsolat offline állapotban van.",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "A könyvjelzőzött hivatkozásokat rendszeresen ellenőrzi, és azok, melyek nem érhetők el, itt jelennek meg.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Megoszthatja másokkal a könyvjelzőmappákat. Az összes Önnel megosztott mappa itt jelenik meg.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Egy könyvjelző egyszerre több mappában is lehet. A frissítése az összes másolatot frissíti. A kényelem érdekében az összes ismételt könyvjelző itt jelenik.",
    "Open all selected" : "Az összes kiválasztott megnyitása",
    "Move selection" : "Kiválasztás áthelyezése",
    "Edit tags of selection" : "Kiválasztott címkék szerkesztése",
    "Delete selection" : "Kiválasztás törlése",
    "Select all" : "Összes kiválasztása",
    "Cancel selection" : "Kiválasztás elvetése",
    "Selected {folders} folders and {bookmarks} bookmarks" : "{folders} mappa és {bookmarks} könyvjelző kiválasztva",
    "Do you really want to delete these items?" : "Biztos, hogy törli ezeket az elemeket?",
    "Trash Bin" : "Kuka",
    "Go back" : "Visszalépés",
    "Share folder" : "Mappa megosztása",
    "Select one or more tags" : "Válasszon egy vagy több címkét",
    "New" : "Új",
    "New bookmark" : "Új könyvjelző",
    "New folder" : "Új mappa",
    "Change to grid view" : "Váltás rácsnézetre",
    "Change to list view" : "Váltás listanézetre",
    "Copy RSS Feed of current view" : "Az aktuális nézet RSS-hírcsatornájának másolása",
    "The RSS feed requires authentication with your Nextcloud credentials" : "Az RSS-hírcsatorna hitelesítést igényel a Nextcloud hitelesítő adataival",
    "Search" : "Keresés",
    "Empty trash bin" : "Kuka ürítése",
    "Sort by created date" : "Rendezés létrehozás dátuma szerint",
    "Sort by last modified" : "Rendezés módosítás dátuma szerint",
    "Sort by title" : "Rendezés cím szerint",
    "Sort by click count" : "Rendezés kattintásszám szerint",
    "Sort by manual order" : "Rendezés kézi sorrend szerint",
    "Sort by URL" : "Rendezés webcím szerint",
    "RSS feed copied" : "Az RSS-csatorna másolva",
    "Enter a link" : "Adja meg a hivatkozást",
    "Enter a title" : "Adja meg a címet",
    "No bookmarks found" : "Nem található könyvjelző",
    "{folders} folders and {bookmarks} bookmarks" : " {folders} mappa és {bookmarks} könyvjelző",
    "Welcome to Bookmarks" : "Üdvözli a Könyvjelzők",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Az alkalmazás lehetővé teszi, hogy rendszerezze a kedvenc helyeit a weben. Rendezze mappákba a könyvjelzőit, címkézze fel őket, és ossza meg másokkal! Az alkalmazás rendszeresen ellenőrzi, hogy a hivatkozások elérhetők-e, és megjeleníti a nem elérhető hivatkozásokat. Ha hozzáad egy webes fájlhivatkozást, akkor az automatikus le lesz töltve a Nextcloud Fájlokba. Importálhatja is a más szolgáltatásokból származó könyvjelzőket, vagy közvetlenül szinkronizálhat az összes böngészőjéből az alkalmazással.",
    "Add a bookmark" : "Könyvjelző hozzáadása",
    "Import bookmarks" : "Könyvjelzők importálása",
    "Sync with your browser" : "Szinkronizálás a böngészővel",
    "Select folder" : "Válasszon egy mappát",
    "Enter folder title" : "Adja meg a mappa nevét",
    "Shared by {user}" : "Megosztotta: {user}",
    "Rename folder" : "Mappa átnevezése",
    "Move folder" : "Mappa áthelyezése",
    "Choose folder" : "Válasszon mappát",
    "Submit" : "Beküldés",
    "Cancel" : "Mégse",
    "Deleting bookmarks" : "Könyvjelzők törlése folyamatban",
    "Deleting selection" : "Kiválasztás törlése",
    "Importing bookmarks" : "Könyvjelzők importálása",
    "Moving selection" : "A kijelölés áthelyezése",
    "Adding selection to folders" : "Kijelölés hozzáadása a mappákhoz",
    "All bookmarks" : "Minden könyvjelző",
    "Recent" : "Friss",
    "Shared with you" : "Megosztva Önnel",
    "Files" : "Fájlok",
    "Duplicates" : "Ismétlések",
    "Broken links" : "Megszakadt hivatkozások",
    "New tag" : "Új címke",
    "Search tags" : "Címkék keresése",
    "Delete" : "Törlés",
    "Untagged" : "Nem címkézett",
    "{used} bookmarks of {available} available" : "{used} könyvjelző / {available} elérhető",
    "Bookmarks Settings" : "Könyvjelző beállítások",
    "No bookmarked files" : "Nincsenek könyvjelzőzött fájlok",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "A fájlok, például a fényképek vagy a PDF-ek könyvjelzőit automatikusan menti az Ön Nextcloud fájljaiba, így akkor is megtalálhatja őket, ha a kapcsolat offline állapotban van.",
    "Nothing found" : "Semmi sem található",
    "No broken links" : "Nincsenek törött hivatkozások",
    "No shared folders" : "Nincsenek megosztott mappák",
    "No duplicated bookmarks" : "Nincsenek ismételt könyvjelzők",
    "No deleted bookmarks" : "Nincsenek törölt könyvjelzők",
    "You haven't deleted anything yet." : "Még nem törölt semmi.",
    "No bookmarks here" : "Itt nincsenek könyvjelzők",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Adjon hozzá könyvjelzőket kézzel, vagy importálja egy HTML-fájlból.",
    "Bookmarks settings" : "Könyvjelző beállítások",
    "Import/Export" : "Importálás/exportálás",
    "Export bookmarks" : "Könyvjelzők exportálása",
    "Auto-archiving" : "Automatikus archiválás",
    "Enable archiving" : "Archiválás engedélyezése",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Adja meg egy mappa elérési útját a Fájlokban, ahol a könyvjelzőket tárolni szeretné",
    "Auto-Backup" : "Automatikus biztonsági mentés",
    "Enable backups" : "Biztonsági mentés engedélyezése",
    "Enter the path of a folder in your Files where backups will be stored." : "Adjon meg egy mappaútvonalat a Fájlokból, ahol a biztonsági mentések lesznek tárolva.",
    "Client apps" : "Kliensalkalmazások",
    "Also check out the collection of client apps that integrate with this app: " : "Nézze meg az alkalmazással integrált ügyfélalkalmazások gyűjteményét is: ",
    "Install web app" : "Web alkalmazás telepítése",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Telepítheti az alkalmazást az eszköze kezdőképernyőjére, hogy gyorsan elérje a könyvjelzőit a telefonján. Ha nem tetszik, akkor könnyedén el is távolítja az alkalmazást a kezdőképernyőjéről.",
    "Install on home screen" : "Telepítés a kezdőképernyőre",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Húzza ezt a böngésző könyvjelzőihez, és kattintson rá a weboldal gyors könyvjelzőzéséhez.",
    "Add to {instanceName}" : "Hozzáadás ehhez: {instanceName}",
    "Need help?" : "Segítségre van szüksége?",
    "Support this project" : "Projekt támogatása",
    "Archive path" : "Archívum elérési útvonala",
    "Backup path" : "Biztonsági mentés útvonala",
    "Please select \"Add to home screen\" in your browser menu" : "Válassza a böngésző menüjében a „Hozzáadás a kezdőképernyőhöz” lehetőséget",
    "(Empty title)" : "(Üres cím)",
    "Title" : "Cím",
    "Link" : "Hivatkozás",
    "Untitled folder" : "Névtelen mappa",
    "Root folder" : "Gyökérmappa",
    "Tags" : "Címkék",
    "Select tags and create new ones" : "Válasszon címkéket, vagy hozzon létre újakat",
    "Notes" : "Jegyzetek",
    "Notes for this bookmark …" : "Megjegyzések a könyvjelzőhöz…",
    "Archived file" : "Archivált fájl",
    "Download file" : "Fájl letöltése",
    "Open file location" : "Fájl helyének megnyitása",
    "Created {time} ago" : "Létrehozva ennyi ideje: {time}",
    "Created on {date}" : "Létrehozás dátuma: {date}",
    "Owner" : "Tulajdonos",
    "Sharing" : "Megosztás",
    "Select a user or group" : "Válasszon ki egy felhasználót vagy csoportot",
    "Share link" : "Hivatkozás megosztása",
    "Reading allowed" : "Az olvasás engedélyezett",
    "Copy RSS feed" : "Az RSS/Atom-hírcsatorna másolása",
    "Delete link" : "Hivatkozás törlése",
    "Create public link" : "Nyilvános hivatkozás létrehozása",
    "Resharing allowed" : "Az újra megosztás engedélyezett",
    "Editing allowed" : "A Szerkesztés engedélyezett",
    "Allow editing" : "Szerkesztés engedélyezése",
    "Allow resharing" : "Újra megosztás engedélyezése",
    "Remove share" : "Megosztás eltávolítása",
    "Link copied" : "Hivatkozás másolva",
    "Privacy" : "Adatvédelem",
    "Enable accessing and collecting information from the web pages you add" : "Engedélyezze az információk elérését és összegyűjtését a hozzáadott weboldalakról",
    "Performance" : "Teljesítmény",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "S sok felhasználót tartalmazó példányokon célszerű a fiókonkénti könyvjelzők számát korlátozni.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "A fiókonként maximálisan engedélyezett könyvjelzők száma. (0: nincs korlátozás, ez az alapértelmezés)",
    "Previews" : "Előnézetek",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Ingyenesen regisztrálhat a screeenly.com weboldalon, vagy beállíthatja a saját kiszolgálóját.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API-kulcs",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API-kulcs",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Pageres CLI" : "Pageres CLI",
    "Pageres ENV variables" : "Pageres környezeti változók",
    "Failed to save settings" : "A beállítások mentése sikertelen",
    "Failed to load settings" : "A beállítások betöltése sikertelen",
    "This URL is already bookmarked! Overwrite?" : "Ez a cím már könyvjelzőzve van. Felülírja?",
    "Enter bookmark title" : "Adja meg a könyvjelző címét",
    "Enter bookmark URL" : "Adja meg a könyvjelző URL-jét",
    "Folder" : "Mappa",
    "Root Folder" : "Gyökérmappa",
    "Save" : "Mentés",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "A hálózati hozzáférés alapértelmezés szerint le van tiltva. Nyissa meg a könyvjelzők alkalmazás rendszergazdai beállításait, hogy engedélyezze az előnézetek és a kedvencek beolvasását.",
    "What's new?" : "Újdonságok",
    "What" : "Mit",
    "Failed to count unavailable bookmarks" : "Az elérhetetlen könyvjelzők megszámlálása sikertelen",
    "Failed to count archived bookmarks" : "Az archivált könyvjelzők megszámolása sikertelen",
    "Failed to count duplicated bookmarks" : "Az ismételt könyvjelzők megszámolása sikertelen",
    "Failed to load bookmark" : "A könyvjelző betöltése sikertelen",
    "Failed to find existing bookmark" : "A létező könyvjelző keresése sikertelen",
    "Failed to create bookmark" : "A könyvjelző létrehozása sikertelen",
    "Failed to save bookmark" : "A könyvjelző mentése sikertelen",
    "Failed to move bookmark" : "A könyvjelző áthelyezése sikertelen",
    "Failed to copy bookmark" : "A könyvjelző másolása sikertelen",
    "Failed to delete bookmark" : "A könyvjelző törlése sikertelen",
    "Failed to rename tag" : "A címke átnevezése sikertelen",
    "Failed to load tags" : "A könyvjelző címkéinek betöltése sikertelen",
    "Failed to load folders" : "A mappák betöltése sikertelen",
    "Failed to delete folder" : "A mappa törlése sikertelen",
    "Failed to create folder" : "A mappa létrehozása sikertelen",
    "Failed to fetch bookmarks." : "A könyvjelzők lekérése sikertelen.",
    "Failed to load setting {key}" : "A(z) {key} beállítás betöltése sikertelen",
    "Failed to update share {shareId}" : "A megosztás frissítése sikertelen: {shareId}",
    "Failed to delete share {shareId}" : "A(z) {shareId} megosztás törlése sikertelen",
    "Create bookmarks for mentioned links" : "Könyvjelzők létrehozása a megemlített hivatkozásokhoz",
    "No links found in this message" : "Nincs hivatkozás ehhez az üzenethez",
    "Bookmarks feed" : "Könyvjelzők hírfolyama"
},
"nplurals=2; plural=(n != 1);");
