(()=>{"use strict";const{rE:e}={rE:"15.0.3"},t=`dynamic-cache-${e}#1`,s=`static-cache-${e}#1`,c=["./"];self.addEventListener("install",(e=>{e.waitUntil(caches.open(s).then((e=>e.addAll(c)))),self.skipWaiting()})),self.addEventListener("activate",(e=>{e.waitUntil(caches.keys().then((e=>Promise.all(e.map((e=>e!==s&&e!==t?caches.delete(e):Promise.resolve())))))),self.clients.claim()})),self.addEventListener("fetch",(e=>{e.respondWith(fetch(e.request).then((s=>{const c=s.clone();return"GET"!==e.request.method?s:(console.debug("Caching",{request:e.request}),caches.open(t).then((t=>t.put(e.request,c))).then((()=>s)))})).catch((t=>(console.debug(t),console.debug("Hitting cache",{request:e.request}),caches.match(e.request)))))}))})();
//# sourceMappingURL=bookmarks-service-worker.js.map?v=7f31688647fa1e404003