OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Σελιδοδείκτες",
    "You bookmarked \"%s\"" : "Έχετε προσθέσει τον σελιδοδείκτη «%s»",
    "%1$s bookmarked \"%2$s\"" : "Ο %1$s πρόσθεσε τον σελιδοδείκτη «%2$s»",
    "Someone bookmarked \"%s\"" : "Κάποιος πρόσθεσε τον σελιδοδείκτη «%s»",
    "You deleted \"%s\"" : "Διεγράψατε το «%s»",
    "%1$s deleted \"%2$s\"" : "%1$s διέγραψε «%2$s»",
    "Someone deleted \"%s\"" : "Κάποιος διέγραψε «%s»",
    "You created folder \"%s\"" : "Δημιουργήσατε τον φάκελο «%s»",
    "%1$s created folder \"%2$s\"" : "Ο %1$s δημιούργησε φάκελο «%2$s»",
    "Someone created folder \"%s\"" : "Κάποιος δημιούργησε τον φάκελο «%s»",
    "You moved folder \"%s\"" : "Μετακινήσατε τον φάκελο «%s»",
    "%1$s moved folder \"%2$s\"" : "Ο %1$s μετακίνησε τον φάκελο «%2$s»",
    "Someone moved folder \"%s\"" : "Κάποιος μετακίνησε τον φάκελο «%s»",
    "You deleted folder \"%s\"" : "Διαγράψατε το φάκελο «%s»",
    "%1$s deleted folder \"%2$s\"" : "Ο %1$s διέγραψε το φάκελο «%2$s»",
    "Someone deleted folder \"%s\"" : "Κάποιος διέγραψε το φάκελο «%s»",
    "You shared folder \"%1$s\" with %2$s" : "Διαμοιράσατε το φάκελο «%1$s» με τον %2$s",
    "You shared folder \"%s\" with someone" : "Διαμοιράστε το φάκελο «%s» με κάποιον",
    "%1$s shared folder \"%2$s\" with you" : "Ο %1$s διαμοίρασε το φάκελο «%2$s» μαζί σας",
    "Someone shared folder \"%s\" with you" : "Κάποιος διαμοίρασε το φάκελο «%s» μαζί σας",
    "You unshared folder \"%1$s\" with %2$s" : "Καταργήσατε την κοινή χρήση του φακέλου «%1$s» με τον %2$s",
    "You unshared folder \"%s\" with someone" : "Καταργήσατε την κοινή χρήση του φακέλου «%s» με κάποιον",
    "%1$s unshared folder \"%2$s\" with you" : "Ο %1$s κατάργησε την κοινή χρήση του φακέλου «%2$s» μαζί σας",
    "Someone unshared folder \"%s\" with you" : "Κάποιος κατάργησε την κοινή χρήση του φακέλου «%s» μαζί σας",
    "No file provided for import" : "Κανένα αρχείο για εισαγωγή",
    "Failed to upload file" : "Αποτυχία μεταφόρτωσης αρχείου",
    "Bookmarks shared by %s" : "Σελιδοδείκτες σε κοινή χρήση από %s",
    "Frequent bookmarks" : "Συχνοί σελιδοδείκτες",
    "Recent bookmarks" : "Τελευταίοι σελιδοδείκτες",
    "Bookmark" : "Σελιδοδείκτης",
    "Bookmark deleted" : "Ο σελιδοδείκτης διαγράφηκε",
    "Bookmark created" : "Ο σελιδοδείκτης δημιουργήθηκε",
    "Bookmark moved" : "Ο σελιδοδείκτης μετακινήθηκε",
    "Bookmark updated" : "Ο σελιδοδείκτης ενημερώθηκε",
    "Create bookmark" : "Δημιουργία σελιδοδείκτη",
    "Takes a link and adds it to your collection of bookmarks." : "Αυτή η ενέργεια, παίρνει έναν σύνδεσμο και τον προσθέτει στη συλλογή των σελιδοδεικτών σας.",
    "Enter new title" : "Εισάγετε νέο τίτλο",
    "Select bookmark" : "Επιλογή σελιδοδείκτη",
    "Details" : "Λεπτομέρειες",
    "Rename" : "Μετονομασία",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "Move" : "Μετακίνηση",
    "Do you really want to delete this bookmark?" : "Θέλετε πραγματικά να διαγράψετε αυτόν τον σελιδοδείκτη;",
    "Link copied to clipboard" : "Ο σύνδεσμος αντιγράφηκε στο πρόχειρο",
    "Open all selected" : "Άνοιγμα των επιλεγμένων",
    "Move selection" : "Μετακίνηση επιλογής",
    "Edit tags of selection" : "Επεξεργασία ετικετών για τα επιλεγμένα",
    "Delete selection" : "Διαγραφή επιλογής",
    "Select all" : "Επιλογή όλων",
    "Cancel selection" : "Ακύρωση επιλογής",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Επιλεγμένοι {folders} φάκελοι και {bookmarks} σελιδοδείκτες",
    "Do you really want to delete these items?" : "Θέλετε πραγματικά να διαγράψετε αυτά τα στοιχεία;",
    "Go back" : "Επιστροφή",
    "Share folder" : "Διαμοιρασμός φακέλου",
    "Select one or more tags" : "Επιλέξτε μία ή περισσότερες ετικέτες",
    "New" : "Νέα",
    "New bookmark" : "Νέος σελιδοδείκτης",
    "New folder" : "Νέος φάκελος",
    "Change to grid view" : "Αλλαγή σε προβολή πλέγματος",
    "Change to list view" : "Αλλαγή σε προβολή λίστας",
    "Search" : "Αναζήτηση",
    "Empty trash bin" : "Άδειασμα κάδου",
    "Sort by created date" : "Ταξινόμηση κατά ημερομηνία δημιουργίας",
    "Sort by last modified" : "Ταξινόμηση κατά τελευταία τροποποίηση",
    "Sort by title" : "Ταξινόμηση κατά τίτλο",
    "Sort by click count" : "Ταξινόμηση κατά μέτρηση κλικ",
    "Sort by manual order" : "Ταξινόμηση κατά χειροκίνητη σειρά",
    "RSS feed copied" : "Η ροή πληροφοριών RSS αντιγράφηκε",
    "Enter a link" : "Εισάγετε σύνδεσμο",
    "Enter a title" : "Εισάγετε ένα τίτλο",
    "No bookmarks found" : "Δεν βρέθηκαν σελιδοδείκτες",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} φάκελοι και {bookmarks} σελιδοδείκτες",
    "Add a bookmark" : "Προσθήκη σελιδοδείκτη",
    "Import bookmarks" : "Εισαγωγή σελιδοδεικτών",
    "Sync with your browser" : "Συγχρονισμός με τον περιηγητή σας",
    "Select folder" : "Επιλογή φακέλου",
    "Enter folder title" : "Τίτλος φακέλου",
    "Shared by {user}" : "Διαμοιράστηκε από {user}",
    "Rename folder" : "Μετονομασία φακέλου",
    "Move folder" : "Μετακίνηση φακέλου",
    "Choose folder" : "Επιλογή φακέλου",
    "Submit" : "Υποβολή",
    "Cancel" : "Ακύρωση",
    "Deleting bookmarks" : "Γίνεται διαγραφή σελιδοδεικτών",
    "Deleting selection" : "Γίνεται διαγραφή της επιλογής",
    "Importing bookmarks" : "Γίνεται εισαγωγή σελιδοδεικτών",
    "Moving selection" : "Γίνεται μετακίνηση της επιλογής",
    "All bookmarks" : "Όλοι οι σελιδοδείκτες",
    "Recent" : "Πρόσφατα",
    "Shared with you" : "Διαμοιράστηκε με σας",
    "Files" : "Αρχεία",
    "Broken links" : "Κατεστραμμένοι σύνδεσμοι",
    "New tag" : "Νέα ετικέτα",
    "Search tags" : "Ετικέτες αναζήτησης",
    "Delete" : "Διαγραφή",
    "Untagged" : "Χωρίς ετικέτα",
    "{used} bookmarks of {available} available" : "Διαθέσιμοι  {available} σελιδοδείκτες από {used}",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Οι σελιδοδείκτες σε αρχεία όπως φωτογραφίες ή PDF θα αποθηκευτούν αυτόματα στα αρχεία Nextcloud, ώστε να μπορείτε να τα βρείτε ακόμα και όταν ο σύνδεσμος είναι εκτός σύνδεσης.",
    "No bookmarks here" : "Δεν υπάρχουν σελιδοδείκτες εδώ",
    "Client apps" : "Εφαρμογές πελάτη",
    "Also check out the collection of client apps that integrate with this app: " : "Ελέγξτε επίσης τη συλλογή των εφαρμογών που ενσωματώνονται με αυτήν την εφαρμογή: ",
    "Install web app" : "Εγκατάσταση εφαρμογής ιστού",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Μπορείτε να εγκαταστήσετε αυτήν την εφαρμογή στην αρχική οθόνη της συσκευής σας για γρήγορη πρόσβαση στους σελιδοδείκτες σας στο τηλέφωνό σας. Μπορείτε εύκολα να αφαιρέσετε ξανά την εφαρμογή από την αρχική οθόνη, αν δεν σας αρέσει.",
    "Install on home screen" : "Εγκατάσταση στην αρχική οθόνη",
    "Bookmarklet" : "Εφαρμογίδιο Σελιδοδεικτών",
    "Add to {instanceName}" : "Προσθήκη στο {instanceName}",
    "Need help?" : "Θέλετε βοήθεια;",
    "Archive path" : "Διαδρομή φακέλου αρχειοθέτησης",
    "Please select \"Add to home screen\" in your browser menu" : "Παρακαλούμε επιλέξτε «Προσθήκη στην αρχική οθόνη» από το μενού του περιηγητή",
    "Title" : "Τίτλος",
    "Link" : "Σύνδεσμος",
    "Root folder" : "Αρχικός φάκελος",
    "Tags" : "Ετικέτες",
    "Select tags and create new ones" : "Επιλέξτε ετικέτες και δημιουργήστε νέες",
    "Notes" : "Σημειώσεις",
    "Notes for this bookmark …" : "Σημειώσεις για αυτό το σελιδοδείκτη …",
    "Archived file" : "Αρχειοθετημένο αρχείο",
    "Download file" : "Λήψη αρχείου",
    "Open file location" : "Άνοιγμα τοποθεσίας αρχείου",
    "Created {time} ago" : "Δημιουργήθηκε πριν {time}",
    "Created on {date}" : "Δημιουργήθηκε στις {date}",
    "Owner" : "Κάτοχος",
    "Sharing" : "Διαμοιρασμός",
    "Select a user or group" : "Επιλογή χρήστη ή ομάδας",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Reading allowed" : "Επιτρέπεται η ανάγνωση",
    "Copy RSS feed" : "Αντιγραφή ροής πληροφοριών RSS",
    "Delete link" : "Διαγραφή συνδέσμου",
    "Create public link" : "Δημιουργία δημόσιου συνδέσμου",
    "Editing allowed" : "Επιτρέπεται η επεξεργασία",
    "Allow editing" : "Επιτρέπεται η επεξεργασία",
    "Allow resharing" : "Επιτρέπεται ο επαναδιαμοιρασμός",
    "Remove share" : "Κατάργηση διαμοιρασμού",
    "Link copied" : "Ο σύνδεσμος αντιγράφηκε",
    "Privacy" : "Ιδιωτικότητα",
    "Enable accessing and collecting information from the web pages you add" : "Ενεργοποιήστε την πρόσβαση και συλλογή πληροφοριών των ιστοσελίδων που προσθέτετε",
    "Performance" : "Απόδοση",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Σε μια εγκατάσταση με πολλούς χρήστες μπορεί να είναι χρήσιμο να περιοριστεί ο αριθμός των σελιδοδεικτών ανά λογαριασμό.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Μέγιστος επιτρεπόμενος αριθμός σελιδοδεικτών ανά λογαριασμό. (0 χωρίς όριο; η προεπιλογή δεν έχει όριο)",
    "Previews" : "Προεπισκοπήσεις",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Μπορείτε να εγγραφείτε δωρεάν στο screeenly.com είτε να ρυθμίσετε το δικό σας διακομιστή.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Κλειδί Screeenly API",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API key",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Pageres CLI" : "Pageres CLI",
    "Failed to save settings" : "Αποτυχία αποθήκευσης ρυθμίσεων",
    "Failed to load settings" : "Αποτυχία φόρτωσης ρυθμίσεων",
    "This URL is already bookmarked! Overwrite?" : "Υπάρχει ήδη σελιδοδείκτης με αυτή τη διεύθυνση URL! Αντικατάσταση;",
    "Enter bookmark title" : "Καταχωρίστε έναν τίτλο σελιδοδείκτη",
    "Enter bookmark URL" : "Καταχωρίστε τη διεύθυνση URL σελιδοδείκτη",
    "Folder" : "Φάκελος",
    "Root Folder" : "Αρχικός φάκελος",
    "Save" : "Αποθήκευση",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Η πρόσβαση στο δίκτυο είναι απενεργοποιημένη από προεπιλογή. Μεταβείτε στις ρυθμίσεις διαχειριστή για την εφαρμογή σελιδοδεικτών για να επιτρέψετε την ανάκτηση προεπισκοπήσεων και favicons.",
    "What's new?" : "Τι νέο υπάρχει;",
    "What" : "Τι να κάνετε",
    "Failed to count unavailable bookmarks" : "Αποτυχία μέτρησης μη διαθέσιμων σελιδοδεικτών",
    "Failed to count archived bookmarks" : "Αποτυχία μέτρησης αρχειοθετημένων σελιδοδεικτών",
    "Failed to load bookmark" : "Αποτυχία φόρτωσης σελιδοδείκτη",
    "Failed to find existing bookmark" : "Απέτυχε η εύρεση υπάρχων σελιδοδείκτη",
    "Failed to create bookmark" : "Απέτυχε η δημιουργία σελιδοδείκτη",
    "Failed to save bookmark" : "Απέτυχε η αποθήκευση σελιδοδείκτη",
    "Failed to move bookmark" : "Απέτυχε η μετακίνηση σελιδοδείκτη",
    "Failed to delete bookmark" : "Απέτυχε η διαγραφή σελιδοδείκτη",
    "Failed to rename tag" : "Αποτυχία μετονομασίας ετικέτας",
    "Failed to load tags" : "Απέτυχε η φόρτωση ετικετών",
    "Failed to load folders" : "Απέτυχε η φόρτωση φακέλων",
    "Failed to delete folder" : "Απέτυχε η διαγραφή φακέλου",
    "Failed to create folder" : "Απέτυχε η δημιουργία φακέλου",
    "Failed to fetch bookmarks." : "Αποτυχία λήψης σελιδοδεικτών.",
    "Failed to load setting {key}" : "Αποτυχία φόρτωσης ρυθμίσεων {key}",
    "Failed to update share {shareId}" : "Αποτυχία ενημέρωσης κοινόχρηστου {shareId}",
    "Failed to delete share {shareId}" : "Αποτυχία διαγραφής κοινόχρηστου {shareId}",
    "Bookmarks feed" : "Ροή σελιδοδεικτών"
},
"nplurals=2; plural=(n != 1);");
