OC.L10N.register(
    "bookmarks",
    {
    "Rename" : "Rename",
    "Move" : "Move",
    "Search" : "Search",
    "Cancel" : "منسوخ کریں",
    "Shared with you" : "Shared with you",
    "Delete" : "حذف کریں",
    "Title" : "عنوان",
    "Link" : "Link",
    "Notes" : "Notes",
    "Owner" : "Owner",
    "Share link" : "اشتراک لنک",
    "Folder" : "Folder",
    "Save" : "حفظ"
},
"nplurals=2; plural=(n != 1);");
